@@ -9,9 +9,12 @@
  * Copyright (c) 1999-2003 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: admin_dbmodify.php,v 1.19 2006/03/26 13:11:46 b0zz Exp $
+ * $Id: admin_dbmodify.php,v 1.26 2006/12/03 13:01:27 b0zz Exp $
  */
+
+ob_start();
 require_once(dirname(dirname(__FILE__)) . "/config/owl.php");
+$out = ob_get_clean();
 require_once($default->owl_fs_root . "/lib/disp.lib.php");
 require_once($default->owl_fs_root . "/lib/owl.lib.php");
 require_once($default->owl_fs_root . "/scripts/phpmailer/class.phpmailer.php");
@@ -100,6 +103,11 @@ if (!fIsAdmin(true) and !fIsUserAdmin($userid))
 
 if ($action == "user")
 {
+   if (fIsUserAdmin($userid) and $id == 1)
+   {
+      printError($owl_lang->err_unauthorized);
+   }
+
    $notify = fIntializeCheckBox($notify);
    $attachfile = fIntializeCheckBox($attachfile);
   
@@ -216,29 +224,48 @@ if ($action == "user")
 if ($action == "group")
 {
    global $default;
+
+   if (fIsUserAdmin($userid) and $id == 0)
+   {
+      printError($owl_lang->err_unauthorized);
+   }
+
    $sql = new Owl_DB;
    $sql->query("UPDATE $default->owl_groups_table SET name='$name' where id = '$id'");
-   foreach ($aAddOwlUser as $iUser)
+
+   if (!empty($aRemoveMember))
    {
-      $sql->query("INSERT INTO $default->owl_users_grpmem_table (userid,groupid) VALUES ('$iUser', '$id')");
-   }
-   foreach ($aRemoveMember as $iMemberId)
-   {
-      $sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE userid = '$iMemberId' and groupid = '$id'"); 
+      foreach ($aRemoveMember as $iMemberId)
+      {
+         $sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE userid = '$iMemberId' and groupid = '$id'"); 
+      }
    }
 
-   foreach ($aRemoveGroupAdmin as $iGroupAdminId)
+   if (!empty($aRemoveGroupAdmin))
    {
-      $sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE userid = '$iGroupAdminId' and groupid = '$id'"); 
+      foreach ($aRemoveGroupAdmin as $iGroupAdminId)
+      {
+         $sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE userid = '$iGroupAdminId' and groupid = '$id'"); 
+      }
    }
 
-   $sql->query("DELETE FROM $default->owl_group_grpmem_table WHERE groupid = '$id'"); 
-
-   foreach ($fselectedgroups as $iGroupId)
+   //$sql->query("DELETE FROM $default->owl_users_grpmem_table WHERE groupid = '$id'"); 
+   if (!empty($aAddOwlUser))
    {
-      $sql->query("INSERT INTO $default->owl_group_grpmem_table (groupid, subgroupid) VALUES ('$id', '$iGroupId')");
+      foreach ($aAddOwlUser as $iUser)
+      {
+         $sql->query("INSERT INTO $default->owl_users_grpmem_table (userid,groupid) VALUES ('$iUser', '$id')");
+      }
    }
 
+   if (!empty($fselectedgroups))
+   {
+      foreach ($fselectedgroups as $iGroupId)
+      {
+         $sql->query("INSERT INTO $default->owl_group_grpmem_table (groupid, subgroupid) VALUES ('$id', '$iGroupId')");
+      }
+   } 
+
    owl_syslog(USER_ADMIN, $userid, 0, 0, $owl_lang->log_admin_changed_group . $name . " ID: $id", "ADMIN");
 
    header("Location: index.php?sess=$sess&action=groups&group=$id&change=1");
@@ -617,11 +644,12 @@ if ($action == "edprefs")
 
    if(empty($major_revision))
    {
-      $major_revision = 1;
+      $major_revision = "0";
    }
+
    if(empty($minor_revision))
    {
-      $minor_revision = 0;
+      $minor_revision = "0";
    }
 
    if(empty($doc_id_num_digits))
@@ -698,6 +726,15 @@ if ($action == "edprefs")
    {
       $change_password_every = "0";
    }
+   if (empty($file_security))
+   {
+      $file_security = "0";
+   }
+   if (empty($folder_security))
+   {
+      $folder_security = "0";
+   }
+
    
    $qPrefsQuery = "UPDATE $default->owl_prefs_table SET ";
    $qPrefsQuery .= "email_from='$email_from'";
