@@ -324,7 +324,7 @@ print("<tr><td class=\"admin0\" width=\"100%\" colspan=\"6\">$owl_lang->doc_admi
 
          $dir = dir($default->owl_LangDir);
          $dir->rewind();
-print("<table>");       
+print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">");       
          while ($file = $dir->read())
          {
             if ($file != "." and $file != ".." and $file != "CVS" and $file != "favicon.ico")
@@ -475,7 +475,7 @@ print("</table>");
 
          $fieldlabel->query("SELECT * FROM $default->owl_docfieldslabel_table WHERE doc_field_id ='" . $sql->f("id") ."' ORDER BY locale");
 
-         print("<td align=\"left\"><table width=\"100%\">");
+         print("<td align=\"left\"><table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">");
          $SubTableCountLines = 0;
          while ( $fieldlabel->next_record() )
          {
@@ -549,7 +549,7 @@ print("</table>");
 
 
          print("<td class=\"$sTrClass\" align=\"center\">");
-         print("\n<table class=\"form1\" width=\"100%\">");
+         print("\n<table class=\"form1\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">");
          switch ($sql->f("field_type"))
          {
             case "text":
@@ -621,7 +621,7 @@ print("</table>");
                  $aRadioButtonValues[$i]= $sValues;
                  $i++;
               }
-                 fPrintFormRadio("$owl_lang->doc_field_disp_label $required" , $sql->f("field_name"), "0", $aRadioButtonValues);
+                 fPrintFormDoctypeRadio("$owl_lang->doc_field_disp_label $required" , $sql->f("field_name"), "0", $aRadioButtonValues);
                break;
             case "checkbox":
                if($sql->f("field_values"))
