@@ -9,10 +9,13 @@
  * Author: Steve Bourgeois <owl@bozzit.com>
  * Project Founder: Chris Vincent <cvincent@project802.net>
  * 
- * $Id: index.php,v 1.26 2006/05/02 13:17:58 b0zz Exp $
+ * $Id: index.php,v 1.35 2006/10/25 13:32:57 b0zz Exp $
  */
 
+ob_start();
 require_once(dirname(dirname(__FILE__)) . "/config/owl.php");
+$out = ob_get_clean();
+
 require_once($default->owl_fs_root . "/lib/disp.lib.php");
 require_once($default->owl_fs_root . "/lib/owl.lib.php");
 require_once($default->owl_fs_root . "/lib/security.lib.php");
@@ -67,6 +70,11 @@ if (!empty($group))
    }
 }
 
+if (fIsUserAdmin($userid) and $owluser== 1)
+{
+   printError($owl_lang->err_unauthorized);
+}
+
 include($default->owl_fs_root . "/lib/header.inc");
 include($default->owl_fs_root . "/lib/userheader.inc");
 
@@ -117,7 +125,7 @@ if (!isset($action))
 
 function printusers()
 {
-   global $sess, $default, $owl_lang, $owluser;
+   global $sess, $default, $owl_lang, $owluser, $userid;
    $sql = new Owl_DB;
    $sql_active_sess = new Owl_DB;
 
@@ -131,6 +139,10 @@ function printusers()
                                                                                                                                                                                                   
    while ($sql->next_record())
    {
+      if (fIsUserAdmin($userid) and $sql->f("id") == 1)
+      {
+         continue;
+      }
       $uid = $sql->f("id");
       $username = $sql->f("username");
       $name = $sql->f("name");
@@ -217,6 +229,7 @@ function printusers()
       global $sess, $change, $default, $flush, $userid;
       global $owl_lang;
 
+
       if ($change == 1) 
       {
          fPrintSectionHeader($owl_lang->saved, "admin3");
@@ -362,8 +375,14 @@ function printusers()
          print("<td class=\"form1\">$owl_lang->home_dir:</td>\n");
          print("<td class=\"form1\" width=\"100%\">");
          print("<select class=\"fpull1\" name=\"homedir\" size=\"1\">");
-         print("<option value='1'>" . fid_to_name($sql->f("homedir")) ."</option>\n");
-         print("<option value='" . $sql->f("homedir") ."' selected='selected'>" . fid_to_name($sql->f("homedir")) ."</option>\n");
+         if ($sql->f("homedir") == 1)
+         {
+            print("<option value='1' selected='selected'>" . fid_to_name(1) ."</option>\n");
+         }
+         else
+         {
+            print("<option value='1'>" . fid_to_name(1) ."</option>\n");
+         }
          fPrintHomeDir("1", "--|", $sql->f("homedir"));
          print("</select>\n</td>\n</tr>\n");
 
@@ -371,8 +390,14 @@ function printusers()
          print("<td class=\"form1\">$owl_lang->initial_dir:</td>\n");
          print("<td class=\"form1\" width=\"100%\">");
          print("<select class=\"fpull1\" name=\"firstdir\" size=\"1\">");
-         print("<option value='1'>" . fid_to_name("1") ."</option>\n");
-         print("<option value='" . $sql->f("firstdir") ."' selected='selected'>" . fid_to_name($sql->f("firstdir")) ."</option>\n");
+         if ($sql->f("firstdir") == 1)
+         {
+            print("<option value='1' selected='selected'>" . fid_to_name(1) ."</option>\n");
+         }
+         else
+         {
+            print("<option value='1'>" . fid_to_name(1) ."</option>\n");
+         }
          fPrintHomeDir("1", "--|", $sql->f("firstdir"));
          print("</select>\n</td>\n</tr>\n");
 
@@ -1001,18 +1026,18 @@ function printusers()
          if ($default->owl_LookAtHD == "false")
          {
             fPrintFormCheckBox($owl_lang->owl_lookAtHD, "lookAtHD", "false", "checked", "submit");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"lookAtHD_del\" value=\"$default->owl_lookAtHD_del\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_file_security\" value=\"$default->owl_def_file_security\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_file_group_owner\" value=\"$default->owl_def_file_group_owner\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_file_owner\" value=\"$default->owl_def_file_owner\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_file_title\" value=\"$default->owl_def_file_title\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_file_meta\"  value=\"$default->owl_def_file_meta\"></input></td></tr>");
-            if ($default->advanced_security == 0)
-            {
-               print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_security\" value=\"$default->owl_def_fold_security\"></input></td></tr>");
-            }
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_group_owner\" value=\"$default->owl_def_fold_group_owner\"></input></td></tr>");
-            print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_owner\" value=\"$default->owl_def_fold_owner\"></input></td></tr>");
+            print("\n<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"lookAtHD_del\" value=\"$default->owl_lookAtHD_del\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_file_security\" value=\"$default->owl_def_file_security\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_file_group_owner\" value=\"$default->owl_def_file_group_owner\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_file_owner\" value=\"$default->owl_def_file_owner\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_file_title\" value=\"$default->owl_def_file_title\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_file_meta\"  value=\"$default->owl_def_file_meta\"></input></td>\n</tr>\n");
+            //if ($default->advanced_security == 1)
+            //{
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_security\" value=\"$default->owl_def_fold_security\"></input></td>\n</tr>\n");
+            //}
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_group_owner\" value=\"$default->owl_def_fold_group_owner\"></input></td>\n</tr>\n");
+            print("<tr>\n<td colspan=\"2\"><input type=\"hidden\" name=\"def_fold_owner\" value=\"$default->owl_def_fold_owner\"></input></td>\n</tr>\n");
          } 
          else
          {
@@ -1699,25 +1724,25 @@ function printusers()
 
          if ($default->self_create_homedir == 1)
          {
-            fPrintFormCheckBox("Create User HomeDir:", "self_create_homedir", "1", "checked");
+            fPrintFormCheckBox($owl_lang->create_user_homedir, "self_create_homedir", "1", "checked");
          }
          else
          {
-            fPrintFormCheckBox("CREATE USER HOMEDIR:", "self_create_homedir", "1");
+            fPrintFormCheckBox($owl_lang->create_user_homedir, "self_create_homedir", "1");
          }
 
          if ($default->registration_using_captcha == 1)
          {
-            fPrintFormCheckBox("USE CAPTCHA:", "self_captcha", "1", "checked");
+            fPrintFormCheckBox($owl_lang->use_captcha, "self_captcha", "1", "checked");
          }
          else
          {
-            fPrintFormCheckBox("USE CAPTCHA:", "self_captcha", "1");
+            fPrintFormCheckBox($owl_lang->use_captcha, "self_captcha", "1");
          }
 
          fPrintFormSelectBox($owl_lang->group . ":" , "self_reg_group", $groups, $default->self_reg_group);
 
-         print("<td class=\"form1\">$owl_lang->home_dir:<br /> (CREATED HERE IF create homedir checked)</td>\n");
+         print("<td class=\"form1\">$owl_lang->home_dir" . $owl_lang->created_here . "</td>\n");
          print("<td class=\"form1\" width=\"100%\">");
          print("<select class=\"fpull1\" name=\"self_reg_homedir\" size=\"1\">");
          print("<option value=\"1\" selected=\"selected\">" . fid_to_name("1") ."</option>\n");
@@ -1767,12 +1792,12 @@ function printusers()
       }
    
       fPrintSectionHeader($owl_lang->owl_title_tools);
-      fPrintFormTextLine($owl_lang->virus_path , "virus_path", 60, $default->virus_path);
+      fPrintFormTextLine(fStatusImage($default->virus_path) .$owl_lang->virus_path , "virus_path", 60, $default->virus_path);
       fPrintFormTextLine(fStatusImage($default->dbdump_path) . $owl_lang->owl_dbdump_path , "dbdump_path", 60, $default->dbdump_path);
       fPrintFormTextLine(fStatusImage($default->gzip_path) . $owl_lang->owl_gzip_path , "gzip_path", 60, $default->gzip_path);
       fPrintFormTextLine(fStatusImage($default->tar_path) . $owl_lang->owl_tar_path , "tar_path", 60, $default->tar_path);
       fPrintFormTextLine(fStatusImage($default->unzip_path) . $owl_lang->owl_unzip_path , "unzip_path", 60, $default->unzip_path);
-      fPrintFormTextLine($owl_lang->owl_pod2html_path , "pod2html_path", 60, $default->pod2html_path);
+      fPrintFormTextLine(fStatusImage($default->pod2html_path) . $owl_lang->owl_pod2html_path , "pod2html_path", 60, $default->pod2html_path);
       fPrintFormTextLine(fStatusImage($default->rtftotext_path) . $owl_lang->rtftotext_path , "rtftotext_path", 60, $default->rtftotext_path);
       fPrintFormTextLine(fStatusImage($default->pdftotext_path) . $owl_lang->owl_pdftotext_path , "pdftotext_path", 60, $default->pdftotext_path);
       fPrintFormTextLine(fStatusImage($default->wordtotext_path) . $owl_lang->owl_wordtotext_path , "wordtotext_path", 60, $default->wordtotext_path);
@@ -1781,6 +1806,11 @@ function printusers()
          printfileperm($default->file_perm, "file_security", $owl_lang->owl_def_file_perm, "admin");
          printgroupperm($default->folder_perm, "folder_security", $owl_lang->owl_def_folder_perm, "user");
       }
+      else
+      {
+         print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"file_security\" value=\"" . $default->file_perm . "\"></input></td></tr>\n");
+         print("<tr><td colspan=\"2\"><input type=\"hidden\" name=\"folder_security\" value=\"" . $default->folder_perm . "\"></input></td></tr>\n");
+      }
       print("<tr>\n");
       print("<td class=\"form2\" width=\"100%\" colspan=\"2\">\n");
       fPrintSubmitButton($owl_lang->change, $owl_lang->alt_change);
@@ -1789,33 +1819,53 @@ function printusers()
       print("</tr>\n");
    } 
 
+function fGetProgram ( $path )
+{
+   $aSplitPath = explode(" ", $path);
+
+   $sReturnPath = "";
+
+   foreach ($aSplitPath as $piece)
+   {
+     $sReturnPath .= $piece . " ";
+
+      if (file_exists(trim($sReturnPath)))
+      {
+         return trim($sReturnPath);
+      }
+   }
+   return "";
+}
+
 
 function fStatusImage ( $path )
 {
    global $default, $owl_lang;
+   
+   $path = fGetProgram ($path);
 
-      if (substr(php_uname(), 0, 7) != "Windows")
+   if (substr(php_uname(), 0, 7) != "Windows")
+   {
+      if(is_executable($path) and is_file($path))
       {
-         if(is_executable($path) and is_file($path))
-         {
-            $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/gstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_green\" border=\"0\"></img>";
-         }
-         else
-         {
-            $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/rstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_red\" border=\"0\"></img>";
-         }
+         $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/gstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_green\" border=\"0\"></img>";
       }
       else
       {
-         if(file_exists($path) and is_file($path))
-         {
-            $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/gstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_green\" border=\"0\"></img>";
-         }
-         else
-         {
-            $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/rstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_red\" border=\"0\"></img>";
-         }
+         $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/rstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_red\" border=\"0\"></img>";
       }
+   }
+   else
+   {
+      if(file_exists($path) and is_file($path))
+      {
+         $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/gstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_green\" border=\"0\"></img>";
+      }
+      else
+      {
+         $sStatusImage = "<img src=\"$default->owl_graphics_url/$default->sButtonStyle/ui_icons/rstatus.gif\" alt=\"$owl_lang->alt_tool_status\" title=\"$owl_lang->alt_tool_status_red\" border=\"0\"></img>";
+      }
+   }
    return $sStatusImage;
 }
 
