@@ -12,11 +12,17 @@
 $dStartTime = time();
 
 require_once(dirname(__FILE__) . "/config/owl.php");
+
+
 require_once($default->owl_fs_root . "/lib/disp.lib.php");
 require_once($default->owl_fs_root . "/lib/owl.lib.php");
 require_once($default->owl_fs_root . "/lib/readhd.php");
 require_once($default->owl_fs_root . "/lib/security.lib.php");
 
+//global $cCommonDBConnection;
+//$cCommonDBConnection = new Owl_DB;
+//$cCommonDBConnection->connect();
+
 if (!isset($expand) or !is_numeric($expand)) 
 {
    $expand = $default->expand;
@@ -223,8 +229,9 @@ if (check_auth($parent, "folder_view", $userid, false, false) != "1" and !$bDown
 
 // Tiian changes 2003-07-31
 $sql_bro = new Owl_DB;
-$sql_bro->query("SELECT id FROM $default->owl_folders_table WHERE id = '$parent' AND name = '$default->version_control_backup_dir_name'");
 
+$sql_bro->query("SELECT id FROM $default->owl_folders_table WHERE id = '$parent' AND name = '$default->version_control_backup_dir_name'");
+("SELECT id FROM $default->owl_folders_table WHERE id = '$parent' AND name = '$default->version_control_backup_dir_name'");
 if ($sql_bro->num_rows() > 0)
 {
     $is_backup_folder = true; 
@@ -260,7 +267,7 @@ if ($default->hide_backup == 1 and !fIsAdmin())
    if ($sql->num_rows() > 0)
    {
       $DBFolderCount++; //count number of filez in db 2 use with array
-      $DBFolders[$DBFolderCount] = '$default->version_control_backup_dir_name'; //create list if files in
+      $DBFolders[$DBFolderCount] = $default->version_control_backup_dir_name; //create list if files in
    } 
 
    $whereclause = " AND name <> '$default->version_control_backup_dir_name'";
@@ -348,17 +355,29 @@ print("<center>");
 
 if ($default->owl_version_control == 1 && ! $default->owl_use_fs)
 {           
-   $qGetFiles = "SELECT f1.id as file_id , f1.major_revision, f1.minor_revision, f1.major_revision+(f1.minor_revision/1000.0) AS mval FROM files f1, files f2 WHERE f1.name=f2.name AND f1.parent=f2.parent AND f1.parent='$parent' AND f1.approved ='1' GROUP BY f1.id, f1.major_revision, f1.minor_revision, f1.$order HAVING f1.major_revision+(f1.minor_revision/1000.0) = max(f2.major_revision+(f2.minor_revision/1000.0)) ORDER BY f1.$order $sort";
+   if ($order == "major_minor_revision")
+   {
+      $order = "major_revision $sort, f1.minor_revision ";
+      $forder = "major_revision $sort, minor_revision ";
+   }
+   else
+   {
+      $forder = $order;
+   }
+
+   $qGetFiles = "SELECT f1.id as file_id , f1.major_revision, f1.minor_revision, f1.major_revision+(f1.minor_revision/1000.0) AS mval FROM $default->owl_files_table f1, $default->owl_files_table f2 WHERE f1.name=f2.name AND f1.parent=f2.parent AND f1.parent='$parent' AND f1.approved ='1' GROUP BY f1.id, f1.major_revision, f1.minor_revision, f1.$order HAVING f1.major_revision+(f1.minor_revision/1000.0) = max(f2.major_revision+(f2.minor_revision/1000.0)) ORDER BY f1.$order $sort";
 
     $sql->query($qGetFiles);
 
-    $FileQuery = ("SELECT * FROM $default->owl_files_table where '1' = '0'");
+    $FileQuery = ("SELECT * FROM $default->owl_files_table where '1' = '0' ");
 
     while ($sql->next_record())
     {
       $FileQuery .= " OR id = '" . $sql->f("file_id") ."'"; 
     }
 
+    $FileQuery .= " ORDER BY $forder $sort";
+
    //$FileQuery = "select f1.*, f1.major_revision+(f1.minor_revision/1000.0) as mval from $default->owl_files_table f1, $default->owl_files_table f2 where f1.approved = '1' and f1.name=f2.name AND f1.parent=f2.parent AND f1.parent=$parent group by f1.id having f1.major_revision+(f1.minor_revision/1000.0) = max(f2.major_revision+(f2.minor_revision/1000.0)) order by f1.$order $sort";
    //$FileQuery = "select f1.*, f1.major_revision+(f1.minor_revision/1000.0) as mval from $default->owl_files_table f1, $default->owl_files_table f2 where f1.name=f2.name AND f1.parent=f2.parent AND f1.parent=$parent group by f1.id having f1.major_revision+(f1.minor_revision/1000.0) = max(f2.major_revision+(f2.minor_revision/1000.0)) order by f1.$order $sort";
 
@@ -396,7 +415,7 @@ if ($default->records_per_page > 0)
 }
 
 
-if ($order == "creatorid")
+if ($order == "creatorid" or $order == "smodified")
 {
    $FolderQuery = "SELECT * from $default->owl_folders_table where parent = '$parent' $whereclause order by $order $sortname $sLimit";
 }
