@@ -1,17 +1,10 @@
 <?php
 /*
-
-  File: owl.php
-  Author: Chris
-  Date: 2000/12/14
-
-  Owl: Copyright Chris Vincent <cvincent@project802.net>
-
-  You should have received a copy of the GNU Public
-  License along with this package; if not, write to the
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
-
+ *  File: owl.php
+ * Author: Steve Bourgeois <owl@bozzit.com>
+ * Project Founder: Chris Vincent <cvincent@project802.net>
+ *
+ * Copyright (c) 1999-2006 The Owl Project Team
 */
 
 // Some urls
@@ -29,15 +22,14 @@ $default->system_ButtonStyle	= "rsdx_blue1";
 // Directory where owl is located
 // this is the full physical path to where
 // Owl was installed
-$default->owl_fs_root		= "/var/www/html/owl-0.90";
+
+$default->owl_fs_root		= dirname(dirname(__FILE__));
 $default->owl_LangDir		= $default->owl_fs_root . "/locale";
 
 // Directory where The Documents Directory is On Disc
 // This path should not include the Documents directory name
 // only the path leading to it.
 
-//$default->owl_FileDir           =  "/var/www/html/owl-0.90";
-
 // NOTE: There should be a directory writeable by the web server
 //       called Documents in $default->owl_FileDir.  If you want to make 
 //	 that a different name you need to rename this directory to what 
@@ -52,8 +44,8 @@ $default->owl_LangDir		= $default->owl_fs_root . "/locale";
 
 // Use the file system of the database to store the
 // files uploaded.
-// $default->owl_use_fs            = true		// This stores uploaded files to the Hard Drive
-// $default->owl_use_fs            = false		// This stores uploaded files to a table in the database
+// $default->owl_use_fs            = true;		// This stores uploaded files to the Hard Drive
+// $default->owl_use_fs            = false;		// This stores uploaded files to a table in the database
 // Note that temporary files are created to gzip files
 // so set to something that is valid, and is writable by the web server
 // For Example: $default->owl_FileDir           =  "/tmp/OWLDB";
@@ -225,7 +217,7 @@ $default->generic_date_format 	= "";
 //**********************************************
 
 
-//$default->lookHD_ommit_ext[] = "db";
+//$default->lookHD_ommit_ext[] = "DS_Store";
 //$default->lookHD_ommit_ext[] = "txt";
 
 
@@ -269,15 +261,17 @@ $default->lookHD_ommit_directory[] = "CVS";
 $default->owl_default_db = 0;    // This indicates what database should be selected by Default  when multiple repositories are defined
 
 // First Database Information
+
 $default->owl_db_id[0]           = "0";
 $default->owl_db_user[0]           = "root";
 $default->owl_db_pass[0]           = "";
 $default->owl_db_host[0]           = "localhost";
-$default->owl_db_name[0]           = "intranet";
+$default->owl_db_name[0]           = "owl090";
 $default->owl_db_display_name[0]   = "Intranet";
 $default->owl_db_ldapserver[0]     = "your.ldap.server.address";
 $default->owl_db_ldapdomain[0]     = "";
-$default->owl_db_FileDir[0]        =  "/var/www/html/owl-0.90";
+//$default->owl_db_FileDir[0]        =  "/var/www/html/owl-0.90";
+$default->owl_db_FileDir[0]        =  $default->owl_fs_root;
 $default->peer_auto_publish[0] 	   = "false";
 
 // Second Database
@@ -286,13 +280,14 @@ $default->peer_auto_publish[0] 	   = "false";
 //$default->owl_db_user[1]           = "root";
 //$default->owl_db_pass[1]           = "";
 //$default->owl_db_host[1]           = "localhost";
-//$default->owl_db_name[1]           = "owl090de";
-//$default->owl_db_display_name[1]   = "Consulting";
+//$default->owl_db_name[1]           = "test";
+//$default->owl_db_display_name[1]   = "Testing";
 //$default->owl_db_ldapserver[1]     = "your.ldap.server.address";
 //$default->owl_db_ldapdomain[1]     = "";
-//$default->owl_db_FileDir[1]           =  "/var/www/html/owl-0.90";
-//$default->peer_auto_publish[1] = "true";
-//
+//$default->owl_db_FileDir[1]           =  $default->owl_fs_root;
+//$default->peer_auto_publish[1] = "false";
+
+
 // Third Database and so on and so on....
 
 //**********************************************
@@ -301,15 +296,16 @@ $default->peer_auto_publish[0] 	   = "false";
 
 // This is to display the version information in the footer
 
-$default->version = "Owl 0.90 20060502";
+$default->version = "Owl 0.94 20070205";
 $default->site_title = "Owl Intranet ";
 $default->phpversion = "4.3.10";
 
-$default->debug = false;
+$default->debug = true;
 
 // BEGIN Drop Down Menu Order
 
 $default->FolderMenuOrder = array(
+'folder_view', 
 'folder_delete', 
 'folder_edit', 
 'folder_copy', 
@@ -448,7 +444,7 @@ $default->auth_host = "192.168.11.41";
 
 // Auth 3 LDAP
 
-$default->ldapserver = "YOUR.LDAP.SERVER.ADDRESS";
+//$default->ldapserver = "lclntn7e.ngco.com";
 
 $default->ldapserverroot = "ou=People,dc=??????,dc=???";
 $default->ldapuserattr = "uid"; // whatever holds logon name in your ldap schema
@@ -463,14 +459,14 @@ $default->ldapprotocolversion = "3"; // or 2 to match your ldap
 // true ---> track it as yet, i.e. (sessid,uid,ip)
 //
 // false --> track it alternate, i.e. (sessid,uid)
-$default->active_session_ip = true;
+$default->active_session_ip = false;
 
 //************************************************************
 // NEW OPTIONS
 //************************************************************
 
 $default->thumbnails_url = $default->owl_root_url . "/ThumbNails"; // this directory has to be in the webspace
-$default->thumbnails_location = "/var/www/html/owl-0.90/ThumbNails"; // this directory has to be in the webspace
+$default->thumbnails_location = $default->owl_fs_root  . "/ThumbNails"; // this directory has to be in the webspace
 
 // Video image types that will be processed with mplayer
 
@@ -489,11 +485,12 @@ $default->thumbnail_image_type[] = "tiff";
 $default->thumbnail_image_type[] = "tif";
 $default->thumbnail_image_type[] = "eps";
 $default->thumbnail_image_type[] = "ai";
+$default->thumbnail_image_type[] = "pdf";
+$default->thumbnail_image_type[] = "doc";
+
 
 
 // BEGIN NEW ACL Based Security Model
-// Old Security Model has not been TESTED
-//
 
 $default->advanced_security = 1;
 
@@ -563,14 +560,15 @@ $default->notify_of_admin_login_email = "security_manager@yourdomain.com";
 
 // When a file is downloaded this will append the Major, Minor version numbers 
 // to the downloaded file name
-
 $default->append_doc_version_to_downloaded_files = 0;
 
 $default->machine_time_zone = -5;
 
+
 $default->make_file_indexing_user_selectable = 0;
 $default->count_file_folder_special_access = false;
 
+
 // *************************************************************
 // List of Special DROP ZONE Folders
 // The idea here is to allow anybody to upload a document to this
@@ -601,17 +599,53 @@ $default->version_control_backup_dir_name = "backup";
 
 $default->purge_historical_documents_days = 90;
 
-$default->default_doctype = 1;
+$default->default_doctype = 2;
 $default->default_url_doctype = 1;
 
 // On file and folder creation the ACL's of the parent are applied 
 // to the new file or folder
 $default->inherit_acl_from_parent_folder = true;
 
+
+// Should be 1 or 0, for whether monitoring a folder 
+// also monitors subfolders under it 
+$default->owl_monitor_subfolders = 1; 
+
+
 // Replace all textareas in Owl with Richtext editor
 $default->use_wysiwyg_for_textarea = 0;
 
-// This kicks everyone Off for maintenance Mode
 $default->owl_maintenance_mode = 0;
 
+//$default->pdf_watermark_path = "/usr/bin/pdftk-disabled";
+// if you have pdttk version 1.41 or higer installed set this one to 1 else set it to 0
+
+$default->pdf_pdftk_tool_greater_than_1_40 = 1;
+
+$default->pdf_watermark_path = "/usr/bin/pdftk";
+$default->pdf_thumb_path = "/usr/bin/pdftoppm";
+$default->pdf_custom_watermark_filepath = ""; // LEAVE Empty unless you created your own background pdf file
+
+// this enables a popup window on setacl
+// that shows the users that are in the group.
+//
+$default->show_users_in_group = true;
+
+// Email notification generates a valid session for users so
+// they don't have to login, to turn this feature off and
+// force the user to sign on before they get access to the file
+// set this value to false
+
+$default->generate_notify_link_session = true;
+
+// when Owl Use FS = False the default was to delete
+// files that where imported and stored to the database
+// to NOT delete your physical files on import set this
+// to FALSE
+$default->use_fs_false_remove_files_on_load = true;
+
+// MegaUpload Progress Bar
+$default->use_progress_bar = 0;
+$default->progress_bar_tmp_dir = "/tmp";
+
 ?>
