@@ -8,9 +8,15 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: index.php,v 1.11 2006/03/06 17:39:34 b0zz Exp $
+ * small change here
+ * 
+ * $Id: index.php,v 1.18 2007/01/05 15:22:07 b0zz Exp $
  */
+
+ob_start();
 if (bcheckLibExists(dirname(__FILE__)."/config/owl.php")) require_once(dirname(__FILE__)."/config/owl.php");
+$out = ob_get_clean();
+
 if (bcheckLibExists($default->owl_fs_root ."/lib/disp.lib.php")) require_once($default->owl_fs_root ."/lib/disp.lib.php");
 
 $default->owl_lang =  fGetBrowserLanguage();
@@ -57,7 +63,15 @@ if (isset($_COOKIE["owl_sessid"]) and $default->remember_me)
             $dNow = $sql->now();
             $sql->query("update $default->owl_users_table set curlogin = $dNow WHERE id = '$uid'");
 
-            header("Location: browse.php?sess=$sess");
+            
+            if (isset($parent) and is_numeric($parent))
+            {
+               header("Location: browse.php?sess=$sess&parent=$parent");
+            }
+            else
+            {
+               header("Location: browse.php?sess=$sess");
+            }
             exit;
          }
       }
@@ -78,7 +92,7 @@ else
 
 function fPrintLoginPage($message = "")
 {
-   global $default, $owl_lang, $language, $parent, $fileid, $anon_disabled ;
+   global $default, $owl_lang, $language, $parent, $fileid, $anon_disabled, $folderid ;
 
 
    print("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\">\n");
@@ -100,11 +114,23 @@ function fPrintLoginPage($message = "")
    print("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\">");
    print("<form name=\"login\" action=\"index.php\" method=\"post\">");
    
-   if (isset($fileid))
+   if (isset($fileid) and is_numeric($fileid))
    {
       print "<input type=\"hidden\" name=\"parent\" value=\"$parent\"></input>\n";
       print "<input type=\"hidden\" name=\"fileid\" value=\"$fileid\"></input>\n";
    }
+   else
+   {
+      if (isset($parent) and is_numeric($parent))
+      {
+         print "<input type=\"hidden\" name=\"parent\" value=\"$parent\"></input>\n";
+      }
+   }
+
+   if (isset($folderid) and is_numeric($folderid))
+   {
+      print "<input type=\"hidden\" name=\"folderid\" value=\"$folderid\"></input>\n";
+   }
 
    print("<tr>\n");
    print("  <td width=\"50%\">&nbsp;<br /></td>\n");
@@ -227,7 +253,7 @@ function fPrintLoginPage($message = "")
    print("</table>");
 
    print("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\">\n");
-   print("<tr><td class=\"version1\" width=\"15%\"><a href=\"http://validator.w3.org/check?uri=referer\"><img src=\"http://www.w3.org/Icons/valid-xhtml10\" alt=\"Valid XHTML 1.0 Transitional\" height=\"31\" width=\"88\" border=\"0\"/></a></td><td class=\"version1\" align=\"center\" width=\"70%\"><a class=\"version2\" href=\"http://owl.sourceforge.net/\" target=\"_blank\">" . $owl_lang->engine . ", " . $owl_lang->version . " " . $default->version . "</a></td><td class=\"version1\" width=\"15%\">&nbsp;</td></tr>\n");
+   print("<tr><td class=\"version1\" width=\"15%\">&nbsp;</td><td class=\"version1\" align=\"center\" width=\"70%\"><a class=\"version2\" href=\"http://owl.sourceforge.net/\" target=\"_blank\">" . $owl_lang->engine . ", " . $owl_lang->version . " " . $default->version . "</a></td><td class=\"version1\" width=\"15%\">&nbsp;</td></tr>\n");
    print("</table>\n");
 }
 
@@ -312,13 +338,25 @@ if (($_POST[loginname]) or ($default->auth == 1 and $_POST[loginname] and $login
              exit;
           }
           
+          if (isset($parent) and is_numeric($parent))
+          {
+             $verified["homedir"] = $parent;
+          }
           if ( $sql->f("change_paswd_at_login") == 1 or $diffd > $default->change_password_every)
           {
-             if (!fIsAdmin())
+             if ( $sql->f("change_paswd_at_login") == 1)
              {
-                header("Location: register.php?myaction=changepass&uid=" . $verified["uid"] . "&parent=" . $verified["homedir"] . "&DIFF=$diffd&LASTCHANGED=" .$dLastChanged . "&DEFAULT=" .$default->change_password_every ."&c=" . $default->owl_current_db);
+                header("Location: register.php?myaction=changepass&uid=" . $verified["uid"] . "&parent=" . $verified["homedir"] . "&c=" . $default->owl_current_db);
                 exit;
              }
+             else
+             {
+                if (!fIsAdmin() and $default->change_password_every > 0)
+                {
+                   header("Location: register.php?myaction=changepass&uid=" . $verified["uid"] . "&parent=" . $verified["homedir"] . "&c=" . $default->owl_current_db);
+                   exit;
+                }
+             }
           } 
           $userid = $verified["uid"];
           $usergroupid = $verified["group"];
