@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: modify.php,v 1.16 2006/03/06 17:39:34 b0zz Exp $
+ * $Id: modify.php,v 1.30 2007/02/05 18:09:53 b0zz Exp $
  */
 
 require_once(dirname(__FILE__)."/config/owl.php");
@@ -52,11 +52,7 @@ if ($action == "file_comment")
    {
       printModifyHeader();
       $sql = new Owl_DB; 
-      $sql->query("SELECT * from $default->owl_comment_table where id = '$cid'");
-      $sql->next_record();
-      $sCommentValue = $sql->f("comments");
 
-      $sql->query("SELECT * from $default->owl_comment_table where fid = '$id' order by id");
 
       fPrintNavBar($parent, $owl_lang->adding_comments . "&nbsp;", $id);
       $urlArgs2 = $urlArgs;
@@ -66,8 +62,13 @@ if ($action == "file_comment")
       if(!empty($cid))
       {
          $urlArgs2['cid']     = $cid;
+         $sql->query("SELECT * from $default->owl_comment_table where id = '$cid'");
+         $sql->next_record();
+         $sCommentValue = $sql->f("comments");
       }
 
+      $sql->query("SELECT * from $default->owl_comment_table where fid = '$id' order by id");
+
       print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
       print fGetHiddenFields ($urlArgs2);
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
@@ -115,7 +116,7 @@ if ($action == "file_comment")
             $urlArgs2['cid']    = $sql->f("id");
             $urlArgs2['id']     = $id;
             $url = fGetURL ('modify.php', $urlArgs2);
-            print("&nbsp;<a href=\"$url\"><img src=\"$default->owl_graphics_url/$default->sButtonStyle/icon_action/edit.gif\" alt=\"$owl_lang->alt_del_comments $file\" title=\"$owl_lang->alt_del_comments $file\" border=\"0\"></img></a>");
+            print("&nbsp;<a href=\"$url\"><img src=\"$default->owl_graphics_url/$default->sButtonStyle/icon_action/edit.gif\" alt=\"$owl_lang->alt_edt_comments $file\" title=\"$owl_lang->alt_edt_comments $file\" border=\"0\"></img></a>");
          } 
 
          print("</td>\n<td class=\"title1\" align=\"left\">$owl_lang->comments_added<b><font color=\"green\">" . uid_to_name($sql->f("userid")) . "</font></b></td>\n</tr>\n");
@@ -151,7 +152,6 @@ if ($action == "file_comment")
 
 if ($action == "file_update" or $action == "edit_inline")
 {
-   //if (check_auth($id, "file_modify", $userid) == 1)
    if (check_auth($id, "file_update", $userid) == 1)
    {
       $sql = new Owl_DB;
@@ -191,7 +191,18 @@ if ($action == "file_update" or $action == "edit_inline")
 
       fPrintNavBar($parent, $owl_lang->updating . ":&nbsp;", $id);
 
-      print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
+      if ($default->use_progress_bar == 1)
+      {
+         $sid = md5(uniqid(rand()));
+         print("<form enctype=\"multipart/form-data\" action=\"/cgi-bin/upload.cgi?sid=$sid\" method=\"post\">\n");
+
+         print("<input type=\"hidden\" name=\"sessionid\" value=\"$sid\"></input>\n");
+      }
+      else
+      {
+         print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
+      }
+
       print fGetHiddenFields ($urlArgs2);
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
       print("<tr>\n");
@@ -217,8 +228,6 @@ if ($action == "file_update" or $action == "edit_inline")
 
       if ( $default->document_peer_review == 1 and empty($type))
       {
-         //$sql->query("SELECT distinct id, name, username, email,language,attachfile from $default->owl_users_table u left join $default->owl_users_grpmem_table m on u.id=m.userid where disabled = '0' and (u.groupid = $usergroupid or m.groupid = $usergroupid) and u.id <> '$userid'");
-
           $aUserList = fGetUserInfoInMyGroups($userid, "email <> '' and id <> '$userid'");
           $i = 0;
           if (!empty($aUserList))
@@ -229,13 +238,9 @@ if ($action == "file_update" or $action == "edit_inline")
                 $sId = $aUsers["id"];
                 $sName = $aUsers["name"];
                 $sEmail = $aUsers["email"];
-            //while ($sql->next_record())
-            //{
-               $reviewer[$i][0] = $sId;
-               $reviewer[$i][1] = $sName . " (" . $sEmail . ")";
-               //$reviewer[$i][0] = $sql->f("id");
-               //$reviewer[$i][1] = $sql->f("name") . " (" . $sql->f("email") . ")";
-               $i++;
+                $reviewer[$i][0] = $sId;
+                $reviewer[$i][1] = $sName . " (" . $sEmail . ")";
+                $i++;
             }
           }
           fPrintFormSelectBox("$owl_lang->peer_reviewer_list" . ":", "reviewers[]", $reviewer, "", 10, true);
@@ -283,14 +288,32 @@ if ($action == "file_update" or $action == "edit_inline")
       print("<td class=\"form2\" width=\"100%\">");
       if ($action == "edit_inline")
       {
-      fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
-      fPrintSubmitButton("Cancel", "Sign File Back in and Close", "submit", "sign_close");
-      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
+         if ($default->use_progress_bar == 1)
+         {
+            $sJscript = " onClick=\"postIt();\"";
+            print("<input  class=\"fbuttonup1\" name=\"send_file_x\" type=\"submit\" value=\"$owl_lang->sendfile\" alt=\"$owl_lang->alt_sendfile\" title=\"$owl_lang->alt_sendfile\" onmouseover=\"highlightButton('fbuttondown1', this)\" onmouseout=\"highlightButton('fbuttonup1', this)\" onClick=\"postIt();\"></input>");
+         }
+         else
+         {
+            fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+         }
+         //fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+         fPrintSubmitButton("Cancel", "Sign File Back in and Close", "submit", "sign_close");
+         fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
       }
       else
       {
-      fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
-      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
+         if ($default->use_progress_bar == 1)
+         {
+            $sJscript = " onClick=\"postIt();\"";
+            print("<input  class=\"fbuttonup1\" name=\"send_file_x\" type=\"submit\" value=\"$owl_lang->sendfile\" alt=\"$owl_lang->alt_sendfile\" title=\"$owl_lang->alt_sendfile\" onmouseover=\"highlightButton('fbuttondown1', this)\" onmouseout=\"highlightButton('fbuttonup1', this)\" onClick=\"postIt();\"></input>");
+         }
+         else
+         {
+            fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+         }
+         //fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+         fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
       }
       print("</td>\n");
       print("</tr>\n");
@@ -327,6 +350,13 @@ if ($action == "file_upload" or $action == "zip_upload")
       $urlArgs2['action'] = $action;
       $urlArgs2['id']     = $id;
       $urlArgs2['type']   = $type;
+
+      if (! $default->owl_version_control == 1)
+      {
+         $urlArgs2['major_revision'] =  $default->major_revision;
+         $urlArgs2['minor_revision'] =  $default->minor_revision;
+      }
+
       if ( $default->advanced_security == 1 )
       {
          $urlArgs2['security']   = "6"; // FILE SECURITY
@@ -357,7 +387,19 @@ if ($action == "file_upload" or $action == "zip_upload")
       }
       $urlArgs2['MAX_FILE_SIZE'] = $default->max_filesize;
 
-      print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
+      if ($default->use_progress_bar == 1)
+      {
+         $sid = md5(uniqid(rand()));
+         print("<form enctype=\"multipart/form-data\" action=\"/cgi-bin/upload.cgi?sid=$sid\" method=\"post\">\n");
+
+         print("<input type=\"hidden\" name=\"sessionid\" value=\"$sid\"></input>\n");
+      }
+      else
+      {
+         print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
+      }
+
+
       print fGetHiddenFields ($urlArgs2);
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
       print("<tr>\n");
@@ -423,7 +465,7 @@ if ($action == "file_upload" or $action == "zip_upload")
          print("<td class=\"form1\" width=\"100%\"><input class=\"finput1\" type=\"text\" id=\"metadata\" name=\"metadata\" size=\"60\" maxlength=\"255\"></input>");
          if ($default->save_keywords_to_db)
          {
-            print("&nbsp;<input class=\"fcheckbox1\" type=\"checkbox\" name=\"savekeyword\" value=\"1\"></input>&nbsp;Save keyword?");
+            print("&nbsp;<input class=\"fcheckbox1\" type=\"checkbox\" name=\"savekeyword\" value=\"1\"></input>&nbsp;" . $owl_lang->save_keyword);
          } 
          print("</td>\n");
          print("</tr>\n");
@@ -596,6 +638,7 @@ if ($action == "file_upload" or $action == "zip_upload")
                      print("</td></tr>");
                      break;
                   case "picklist":
+                    $aPickListValues = array();
                     $aPickList = array();
                   
                     $aPickList = split("\|",  $sql->f("field_values"));
@@ -609,6 +652,7 @@ if ($action == "file_upload" or $action == "zip_upload")
                     fPrintFormSelectBox($qFieldLabel->f("field_label") .": $required", $sql->f("field_name"), $aPickListValues);
                     break;
                  case "mcheckbox":
+                    $aMultipleCheckBox = array();
                     $aMultipleCheckBox = split("\|",  $sql->f("field_values"));
                     $i = 0;
                     $iNumberColumns  = $sql->f("field_size");
@@ -643,6 +687,7 @@ if ($action == "file_upload" or $action == "zip_upload")
 	            print("</td>\n</tr>\n");
                   break;
                   case "radio":
+                     $aRadioButtons = array();
                      $aRadioButtons = split("\|",  $sql->f("field_values"));
                      $i = 0;
                      foreach ($aRadioButtons as $sValues)
@@ -650,7 +695,7 @@ if ($action == "file_upload" or $action == "zip_upload")
                         $aRadioButtonValues[$i]= $sValues;
                         $i++;
                      }
-                     fPrintFormRadio($qFieldLabel->f("field_label") .": $required" , $sql->f("field_name"), "0", $aRadioButtonValues);
+                     fPrintFormDoctypeRadio($qFieldLabel->f("field_label") .": $required" , $sql->f("field_name"), "0", $aRadioButtonValues);
                   break;
                   case "textarea":
                      fPrintFormTextArea($qFieldLabel->f("field_label"). ": $required", $sql->f("field_name"), $sql->f("field_values"), $sql->f("field_size"));
@@ -722,7 +767,17 @@ if ($action == "file_upload" or $action == "zip_upload")
          fPrintButtonSpace(1, 1);
          print("</td>\n");
          print("<td class=\"form2\" width=\"100%\">");
-	 fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+
+         if ($default->use_progress_bar == 1)
+         {
+            $sJscript = " onClick=\"postIt();\"";
+            print("<input  class=\"fbuttonup1\" name=\"send_file_x\" type=\"submit\" value=\"Send File\" alt=\"Send The File\" title=\"Send The File\" onmouseover=\"highlightButton('fbuttondown1', this)\" onmouseout=\"highlightButton('fbuttonup1', this)\" onClick=\"postIt();\"></input>");
+         }
+         else
+         {
+	    fPrintSubmitButton($owl_lang->sendfile, $owl_lang->alt_sendfile, "submit", "send_file_x");
+         }
+
          fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
          print("</td>\n");
          print("</tr>\n");
@@ -748,7 +803,6 @@ if ($action == "file_upload" or $action == "zip_upload")
 
 if ($action == "file_modify")
 {
-   //if (check_auth($id, "file_modify", $userid) == 1)
    if (check_auth($id, "file_property", $userid) == 1)
    {
       printModifyHeader();
@@ -777,7 +831,8 @@ if ($action == "file_modify")
       } 
       else
       {
-         if (uid_to_name($userid) == fid_to_creator($id))
+         $current_groupid = owlfilegroup($id);
+         if (uid_to_name($userid) == fid_to_creator($id) or fIsGroupAdmin($userid, $current_groupid))
          {
             $groups = fGetGroups($userid);
             $mygroup = owlusergroup($userid);
@@ -800,38 +855,39 @@ if ($action == "file_modify")
       $sql->query("SELECT * from $default->owl_files_table where id = '$id'");
       $sql->next_record();
 
-      fPrintNavBar($parent, $owl_lang->modifying . ":&nbsp;", $id);
-      print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
-      if ($sql->f("url") == 1)
-      {
-         print("<input type=\"hidden\" name=\"filename\" value=\"" . $sql->f("filename") . "\"></input>\n");
-         print("<input type=\"hidden\" name=\"type\" value=\"url\"></input>\n");
-      }
-      else
-      {
-         print("<input type=\"hidden\" name=\"filename\" value=\"" . $sql->f("filename") . "\"></input>\n");
-      } 
-
-
-
-      if (owlusergroup($userid) == 0 || uid_to_name($userid) == fid_to_creator($id) || $mygroup == $default->file_admin_group)
-      {
-         if ($default->advanced_security == 1)
-         {
-            print("<input type=\"hidden\" name=\"security\" value=\"" . $sql->f("security") . "\"></input>\n");
-         }
-      }
-      else
-      {
-         print("<input type=\"hidden\" name=\"file_owner\" value=\"" . $sql->f("creatorid") . "\"></input>\n");
-         print("<input type=\"hidden\" name=\"security\" value=\"" . $sql->f("security") . "\"></input>\n");
-         print("<input type=\"hidden\" name=\"groupid\" value=\"" . $sql->f("groupid") . "\"></input>\n");
-      }
-
       $urlArgs2 = $urlArgs;
       $urlArgs2['action']  = 'file_modify';
       $urlArgs2['id']      = $id;
       $urlArgs2['saved_doctype'] = $sql->f("doctype");
+      $urlArgs2['filename']  = $sql->f("filename");
+
+      fPrintNavBar($parent, $owl_lang->modifying . ":&nbsp;", $id);
+      print("<form enctype=\"multipart/form-data\" action=\"dbmodify.php\" method=\"post\">\n");
+      if ($sql->f("url") == 1)
+      {
+         $urlArgs2['type']  = "url";
+      }
+      if (fIsAdmin() || uid_to_name($userid) == fid_to_creator($id) or fIsGroupAdmin($userid, $current_groupid))
+      {
+         if ($default->advanced_security == 1)
+         {
+            $urlArgs2['security']  = $sql->f("security");
+         }
+      }
+      else
+      {
+         $urlArgs2['file_owner']  = $sql->f("creatorid");
+         $urlArgs2['security']  = $sql->f("security");
+         $urlArgs2['groupid']  = $sql->f("groupid");
+      }
+
+
+      if ($default->owl_version_control == 1 and ! fIsAdmin())
+      {
+         $urlArgs2['major_revision']  = $sql->f("major_revision");
+         $urlArgs2['minor_revision']  = $sql->f("minor_revision");
+      }
+
       print fGetHiddenFields($urlArgs2);
 
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
@@ -841,199 +897,201 @@ if ($action == "file_modify")
 
       fPrintDoctypePickList($sql->f("doctype"), "CHANGE");
 
-         fPrintFormTextLine($owl_lang->title . ":" , "title", 60,  $sql->f("name"));
+      fPrintFormTextLine($owl_lang->title . ":" , "title", 60,  $sql->f("name"));
 
-         $link = $default->owl_notify_link . "browse.php?sess=0&amp;parent=" . $parent . "&amp;expand=1&amp;fileid=" . $id;
+      $link = $default->owl_notify_link . "browse.php?sess=0&amp;parent=" . $parent . "&amp;expand=1&amp;fileid=" . htmlentities($id);
 
-         fPrintFormTextLine($owl_lang->notify_link . ":" , "", "",  $link , "", true);
+      fPrintFormTextLine($owl_lang->notify_link . ":" , "", "",  $link , "", true);
 
-         if ($sql->f("url") == 1)
+      if ($sql->f("url") == 1)
+      {
+         $link = "<a href=\"" . $sql->f("filename") . "\" target=\"new\" title=\"$owl_lang->title_browse_site\">" . $sql->f("filename") . "</a>";
+         fPrintFormTextLine($owl_lang->modify_url . ":" , "", "",  $link , "", true);
+         fPrintFormTextLine($owl_lang->file . ":" , "new_filename", 60,  $sql->f("filename"));
+      } 
+      else
+      {
+         fPrintFormTextLine($owl_lang->file . ":" , "new_filename", 40, $sql->f("filename"), gen_filesize($sql->f("f_size")) );
+      } 
+      // if a MP3 tag was found Display the information
+      $filepath = $default->owl_FileDir . "/" . get_dirpath($sql->f("parent")) . "/" . $sql->f("filename");
+      if ($sql->f("url") == 0 && file_exists($filepath))
+      {
+         $id3 = new id3($filepath);
+
+         if ($id3->id3v11 | $id3->id3v1)
          {
-            $link = "<a href=\"" . $sql->f("filename") . "\" target=\"new\" title=\"$owl_lang->title_browse_site\">" . $sql->f("filename") . "</a>";
-            fPrintFormTextLine($owl_lang->modify_url . ":" , "", "",  $link , "", true);
-            fPrintFormTextLine($owl_lang->file . ":" , "new_filename", 60,  $sql->f("filename"));
+            $id3->study();
+            print("<tr><td class=\"form1\"><br />$owl_lang->disp_mp3<br /></td>");
+            print("<td class=\"form1\" width=\"100%\">");
+            print("<b>$id3->artists - $id3->name <br />");
+            print("$id3->album <br />");
+            print("$id3->bitrate kbps&nbsp;&nbsp;$id3->frequency Hz&nbsp;$id3->mode <br />");
+            print("$id3->length<br />");
+            print("$id3->genre<br />");
+            print("$id3->comment</b>");
+            print("</td></tr>");
          } 
-         else
-         {
-            fPrintFormTextLine($owl_lang->file . ":" , "new_filename", 40, $sql->f("filename"), gen_filesize($sql->f("f_size")) );
-         } 
-         // if a MP3 tag was found Display the information
-         $filepath = $default->owl_FileDir . "/" . get_dirpath($sql->f("parent")) . "/" . $sql->f("filename");
-         if ($sql->f("url") == 0 && file_exists($filepath))
-         {
-            $id3 = new id3($filepath);
+      } 
 
-            if ($id3->id3v11 | $id3->id3v1)
+      $security = $sql->f("security");
+      $current_groupid = owlfilegroup($id);
+      $current_owner = owlfilecreator($id);
+
+      if (fIsAdmin() || uid_to_name($userid) == fid_to_creator($id) or fIsGroupAdmin($userid, $current_groupid))
+      {
+         print("<tr>\n");
+         print("<td class=\"form1\">$owl_lang->ownership:</td>\n");
+         print("<td class=\"form1\" width=\"100%\">");
+         print("<select class=\"fpull1\" name=\"file_owner\" size=\"1\">\n");
+
+         foreach($users as $g)
+         {
+            print("<option value=\"$g[0]\" ");
+            if ($g[0] == owlfilecreator($id))
             {
-               $id3->study();
-               print("<tr><td class=\"form1\"><br />$owl_lang->disp_mp3<br /></td>");
-               print("<td class=\"form1\" width=\"100%\">");
-               print("<b>$id3->artists - $id3->name <br />");
-               print("$id3->album <br />");
-               print("$id3->bitrate kbps&nbsp;&nbsp;$id3->frequency Hz&nbsp;$id3->mode <br />");
-               print("$id3->length<br />");
-               print("$id3->genre<br />");
-               print("$id3->comment</b>");
-               print("</td></tr>");
-            } 
+               print("selected=\"selected\"");
+            }
+            print(">$g[1]</option>\n");
          } 
+         print("</select></td></tr>");
 
-         $security = $sql->f("security");
-         $current_groupid = owlfilegroup($id);
-         $current_owner = owlfilecreator($id);
-
-         if (owlusergroup($userid) == 0 || uid_to_name($userid) == fid_to_creator($id) || $mygroup == $default->file_admin_group)
+         if ($default->advanced_security == 0)
          {
             print("<tr>\n");
-            print("<td class=\"form1\">$owl_lang->ownership:</td>\n");
+            print("<td class=\"form1\">$owl_lang->ownergroup:</td>\n");
             print("<td class=\"form1\" width=\"100%\">");
-            print("<select class=\"fpull1\" name=\"file_owner\" size=\"1\">\n");
-
-            foreach($users as $g)
+            print("<select class=\"fpull1\" name=\"groupid\" size=\"1\">\n");
+            foreach($groups as $g)
             {
                print("<option value=\"$g[0]\" ");
-               if ($g[0] == owlfilecreator($id))
+               if ($g[0] == $current_groupid)
                {
                   print("selected=\"selected\"");
                }
                print(">$g[1]</option>\n");
             } 
             print("</select></td></tr>");
-
-            if ($default->advanced_security == 0)
-            {
-               print("<tr>\n");
-               print("<td class=\"form1\">$owl_lang->ownergroup:</td>\n");
-               print("<td class=\"form1\" width=\"100%\">");
-               print("<select class=\"fpull1\" name=\"groupid\" size=\"1\">\n");
-               foreach($groups as $g)
-               {
-                  print("<option value=\"$g[0]\" ");
-                  if ($g[0] == $current_groupid)
-                  {
-                     print("selected=\"selected\"");
-                  }
-                  print(">$g[1]</option>\n");
-               } 
-               print("</select></td></tr>");
-               printfileperm($security, "security", "$owl_lang->permissions:", "admin");
-            }
-         } 
-         else
-         {
-            fPrintFormTextLine($owl_lang->ownership .":", "", "",   fid_to_creator($id) . "&nbsp;(" . group_to_name(owlfilegroup($id)) . ")", "", true);
-         } 
-         // Bozz change End
-         print("<tr>\n");
-         print("<td class=\"form1\">$owl_lang->keywords:</td>\n");
-         print("<td class=\"form1\" width=\"100%\"><input class=\"finput1\" type=\"text\" name=\"metadata\" value=\"" . $sql->f("metadata") . "\"size=\"60\" maxlength=\"255\"></input>");
-         if ($default->save_keywords_to_db)
-         {
-            print("&nbsp;<input class=\"fcheckbox1\" type=\"checkbox\" name=\"savekeyword\" value=\"1\"></input>&nbsp;Save keyword?");
-         } 
-         print("</td>\n");
-         print("</tr>\n");
-
-         if ($default->save_keywords_to_db)
-         {
-            $KeyWrd = new Owl_DB;
-            $KeyWrd->query("SELECT keyword_text from $default->owl_keyword_table order by keyword_text");
-            $i = 0;
-            while ($KeyWrd->next_record())
-            {
-               $keywords[$i][0] = $KeyWrd->f("keyword_text");
-               $keywords[$i][1] = $KeyWrd->f("keyword_text");
-               $i++;
-            }
-            fPrintFormSelectBox("&nbsp;", "keywordpick[]", $keywords, $sql->f("metadata") , 5, true);
+            printfileperm($security, "security", "$owl_lang->permissions:", "admin");
          }
+      } 
+      else
+      {
+         fPrintFormTextLine($owl_lang->ownership .":", "", "",   fid_to_creator($id) . "&nbsp;(" . group_to_name(owlfilegroup($id)) . ")", "", true);
+      } 
+      // Bozz change End
+      print("<tr>\n");
+      print("<td class=\"form1\">$owl_lang->keywords:</td>\n");
+      print("<td class=\"form1\" width=\"100%\"><input class=\"finput1\" type=\"text\" name=\"metadata\" value=\"" . $sql->f("metadata") . "\"size=\"60\" maxlength=\"255\"></input>");
+      if ($default->save_keywords_to_db)
+      {
+         print("&nbsp;<input class=\"fcheckbox1\" type=\"checkbox\" name=\"savekeyword\" value=\"1\"></input>&nbsp;" . $owl_lang->save_keyword);
+      } 
+      print("</td>\n");
+      print("</tr>\n");
 
-
-         if ($default->owl_version_control == 1 and fIsAdmin())
+      if ($default->save_keywords_to_db)
+      {
+         $KeyWrd = new Owl_DB;
+         $KeyWrd->query("SELECT keyword_text from $default->owl_keyword_table order by keyword_text");
+         $i = 0;
+         while ($KeyWrd->next_record())
          {
-            fPrintFormTextLine($owl_lang->vermajor . ":", "major_revision", 5, $sql->f("major_revision"));
-            fPrintFormTextLine($owl_lang->verminor . ":", "minor_revision", 5, $sql->f("minor_revision"));
+            $keywords[$i][0] = $KeyWrd->f("keyword_text");
+            $keywords[$i][1] = $KeyWrd->f("keyword_text");
+            $i++;
          }
-         else
+         fPrintFormSelectBox("&nbsp;", "keywordpick[]", $keywords, $sql->f("metadata") , 5, true);
+      }
+
+      if ($default->owl_version_control == 1 and fIsAdmin())
+      {
+         fPrintFormTextLine($owl_lang->vermajor . ":", "major_revision", 5, $sql->f("major_revision"));
+         fPrintFormTextLine($owl_lang->verminor . ":", "minor_revision", 5, $sql->f("minor_revision"));
+      }
+      else
+      {
+         if ($default->owl_version_control == 1)
          {
             fPrintFormTextLine($owl_lang->vermajor . ":", "major_revision", 5, $sql->f("major_revision"), "", true);
             fPrintFormTextLine($owl_lang->verminor . ":", "minor_revision", 5, $sql->f("minor_revision"), "", true);
          }
+      }
 
-         if ($default->display_password_override == 1)
+      if ($default->display_password_override == 1)
+      {
+         if (fIsAdmin() || uid_to_name($userid) == fid_to_creator($id))
          {
-            if (fIsAdmin() || uid_to_name($userid) == fid_to_creator($id))
-            {
-               fPrintFormTextLine($owl_lang->newpassword . ":" , "newpassword", "", $sql->f("password"), "", false, "password");
-               fPrintFormTextLine($owl_lang->confpassword . ":" , "confpassword", "", $sql->f("password"), "", false, "password");
-            }
+            fPrintFormTextLine($owl_lang->newpassword . ":" , "newpassword", "", $sql->f("password"), "", false, "password");
+            fPrintFormTextLine($owl_lang->confpassword . ":" , "confpassword", "", $sql->f("password"), "", false, "password");
          }
+      }
 
-         if ($sql->f("url") == 2)
+      if ($sql->f("url") == 2)
+      {
+         if ($default->owl_use_fs)
          {
-            if ($default->owl_use_fs)
-            {
-               $filename = $default->owl_FileDir . "/" . find_path($parent) . "/" . $sql->f("filename");
-               $handle = fopen ($filename, "r");
-               $contents = fread ($handle, filesize ($filename));
-               fclose ($handle);
-            } 
-            else
-            {
-               $getdata = new Owl_DB;
-               $getdata->query("SELECT data from $default->owl_files_data_table where id='$id'");
-               $getdata->next_record();
-               $contents = $getdata->f("data");
-            } 
-            fPrintFormTextArea($owl_lang->description. ":", "description", $sql->f("description"));
-            fPrintFormTextArea($owl_lang->note_content. ":", "note_content", $contents, 20, 50);
+            $filename = $default->owl_FileDir . "/" . find_path($parent) . "/" . $sql->f("filename");
+            $handle = fopen ($filename, "r");
+            $contents = fread ($handle, filesize ($filename));
+            fclose ($handle);
          } 
          else
          {
-            fPrintCustomFields ($sql->f("doctype"), $sql->f("id"), $sql->f("required"));
-            if ($default->file_desc_req == "1")
-            {
-               $sRequiredDesc = "<font color=\"red\"><b>&nbsp;*&nbsp;</b></font>";
-            }
-            else
-            {
-               $sRequiredDesc = "<font color=\"red\"><b>&nbsp;&nbsp;&nbsp;</b></font>";
-            }
-            fPrintFormTextArea($owl_lang->description. ":$sRequiredDesc", "description", $sql->f("description"));
-
+            $getdata = new Owl_DB;
+            $getdata->query("SELECT data from $default->owl_files_data_table where id='$id'");
+            $getdata->next_record();
+            $contents = $getdata->f("data");
          } 
-         print("<tr>\n");
-         print("<td class=\"form1\">");
-         fPrintButtonSpace(1, 1);
-         print("</td>\n");
-         print("<td class=\"form2\" width=\"100%\">");
-         fPrintSubmitButton($owl_lang->change, $owl_lang->alt_change);
-         fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
-         print("</td>\n");
-         print("</tr>\n");
-         if ($default->thumbnails == 1)
+         fPrintFormTextArea($owl_lang->description. ":", "description", $sql->f("description"));
+         fPrintFormTextArea($owl_lang->note_content. ":", "note_content", $contents, 20, 50);
+      } 
+      else
+      {
+         fPrintCustomFields ($sql->f("doctype"), $sql->f("id"), $sql->f("required"));
+         if ($default->file_desc_req == "1")
          {
-            $sThumbUrl = $default->thumbnails_url . "/" . $default->owl_current_db . "_" . $sql->f("id") . "_large.png";
-            $sThumbLoc = $default->thumbnails_location . "/" . $default->owl_current_db . "_" . $sql->f("id") . "_large.png";
-            if (file_exists($sThumbLoc))
-            {
-               print("<tr><td class=\"form1\">&nbsp;</td>");
-               print("<td class=\"form1\" width=\"100%\">");
-               print("<img src=\"$sThumbUrl\" border=\"1\"></img>");
-               print("</td></tr>\n");
-            }
+            $sRequiredDesc = "<font color=\"red\"><b>&nbsp;*&nbsp;</b></font>";
          }
-         print("</table>\n");
-         print("</td>\n</tr>\n</table>\n");
-         print("</form>\n");
+         else
+         {
+            $sRequiredDesc = "<font color=\"red\"><b>&nbsp;&nbsp;&nbsp;</b></font>";
+         }
+         fPrintFormTextArea($owl_lang->description. ":$sRequiredDesc", "description", $sql->f("description"));
 
-         if ($default->show_prefs == 2 or $default->show_prefs == 3)
+      } 
+      print("<tr>\n");
+      print("<td class=\"form1\">");
+      fPrintButtonSpace(1, 1);
+      print("</td>\n");
+      print("<td class=\"form2\" width=\"100%\">");
+      fPrintSubmitButton($owl_lang->change, $owl_lang->alt_change);
+      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
+      print("</td>\n");
+      print("</tr>\n");
+      if ($default->thumbnails == 1)
+      {
+         $sThumbUrl = $default->thumbnails_url . "/" . $default->owl_current_db . "_" . $sql->f("id") . "_large.png";
+         $sThumbLoc = $default->thumbnails_location . "/" . $default->owl_current_db . "_" . $sql->f("id") . "_large.png";
+         if (file_exists($sThumbLoc))
          {
-            fPrintPrefs("infobar2");
+            print("<tr><td class=\"form1\">&nbsp;</td>");
+            print("<td class=\"form1\" width=\"100%\">");
+            print("<img src=\"$sThumbUrl\" border=\"1\"></img>");
+            print("</td></tr>\n");
          }
-         print("</td></tr></table>\n");
-         include($default->owl_fs_root ."/lib/footer.inc");
-   } 
+   }
+   print("</table>\n");
+   print("</td>\n</tr>\n</table>\n");
+   print("</form>\n");
+
+   if ($default->show_prefs == 2 or $default->show_prefs == 3)
+   {
+      fPrintPrefs("infobar2");
+   }
+   print("</td></tr></table>\n");
+   include($default->owl_fs_root ."/lib/footer.inc");
+} 
    else
    {
       printError($owl_lang->err_nofilemod);
@@ -1158,7 +1216,7 @@ if ($action == "folder_modify")
       {
          $groups = fGetGroups($userid);
 
-         $sql->query("SELECT id,name from $default->owl_users_table");
+         $sql->query("SELECT id,name FROM $default->owl_users_table ORDER BY name");
          $i = 0;
          while ($sql->next_record())
          {
@@ -1174,7 +1232,7 @@ if ($action == "folder_modify")
             $groups = fGetGroups($userid);
             $mygroup = owlusergroup($userid);
 
-            $sql->query("SELECT id,name from $default->owl_users_table where groupid='$mygroup'");
+            $sql->query("SELECT id,name FROM $default->owl_users_table WHERE groupid='$mygroup' ORDER BY name");
             $i = 0;
             while ($sql->next_record())
             {
@@ -1210,7 +1268,11 @@ if ($action == "folder_modify")
          print("<tr>\n");
          print("<td align=\"left\" valign=\"top\">\n");
          print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
+
          fPrintFormTextLine($owl_lang->name . ":" , "name", 24, $sql->f("name"));
+         $link = $default->owl_notify_link . "browse.php?sess=0&amp;parent=". $id ."&amp;expand=1&amp;fileid=0";
+         fPrintFormTextLine($owl_lang->notify_link . ":" , "", "",  $link , "", true);
+
          if (fIsAdmin() || $userid == owlfoldercreator($id))
          {
             print("<tr>\n");
@@ -1366,7 +1428,6 @@ if ($action == "bulk_email")
    $query = "select * from $default->owl_files_table where ";
    foreach($disp as $fid)
    {
-      //if (check_auth($fid, "file_modify", $userid) == 1)
       if (check_auth($fid, "file_email", $userid) == 1)
       {
                $query .= "id = '" . $fid . "' or ";
@@ -1405,6 +1466,32 @@ if ($action == "bulk_email")
    print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
    fPrintFormCheckBox($owl_lang->attach_file, "fileattached", "1");
    fPrintFormTextLine($owl_lang->email_to , "mailto");
+   $aEmailList = fGetUserInfoInMyGroups($userid, "email <> ''");
+
+      print("<tr>\n");
+      print("<td class=\"form1\">&nbsp;</td>\n");
+      print("<td class=\"form1\" width=\"100%\">");
+      print("<select class=\"fpull1\" name=\"pick_mailto\" size=\"1\">\n");
+      print("<option value=\"\" >" . $owl_lang->pick_select . "</option>\n");
+
+      //while ($sql->next_record())
+      foreach ($aEmailList as $aUsers)
+      {
+         $sUsername = $aUsers["username"];
+         $sName = $aUsers["name"];
+         $sEmail = $aUsers["email"];
+
+         if ($sName == "")
+         {
+            print("<option value=\"" . $sEmail . "\">" . $sUsername . " - (" . $sEmail . ")</option>\n");
+         }
+         else
+         {
+            print("<option value=\"" . $sEmail . "\">" . $sName . " - (" . $sEmail . ")</option>\n");
+         }
+      }
+      print("</select>\n</td>\n</tr>\n");
+
    if ($default->use_smtp)
    {
       fPrintFormTextLine($owl_lang->email_cc , "ccto");
