@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: move.php,v 1.6 2006/04/05 03:02:01 b0zz Exp $
+ * $Id: move.php,v 1.9 2006/08/16 23:50:55 b0zz Exp $
  */
 
 global $order, $sortorder, $sortname;
@@ -24,8 +24,6 @@ if ($sess == "0" && $default->anon_ro > 1)
    printError($owl_lang->err_login);
 }
 
-//print("M: $myaction_x X: $myaction");
-
 if (isset($myaction_x))
 {
    $myaction = "$owl_lang->cancel_button";
@@ -39,7 +37,6 @@ if ($myaction == "$owl_lang->cancel_button")
 } 
 if ($action == "file" or $action == "cp_file" or $action == "lnk_file")
 {
-   //if (check_auth($id, "file_modify", $userid) == 0)
    if (($action == "cp_file" and check_auth($id, "file_cp", $userid) == 0) or (($action == "file" or $action == "lnk_file") and check_auth($id, "file_move", $userid) == 0))
    {
       include($default->owl_fs_root ."/lib/header.inc");
@@ -61,7 +58,6 @@ if ($action == "file" or $action == "cp_file" or $action == "lnk_file")
 elseif ($action == "cp_folder")
 {
    if (check_auth($id, "folder_cp", $userid) == 0)
-   //if (check_auth($id, "folder_modify", $userid) == 0 or check_auth($id, "folder_delete", $userid) == 0 )
    {
       include($default->owl_fs_root ."/lib/header.inc");
       include($default->owl_fs_root ."/lib/userheader.inc");
@@ -71,7 +67,6 @@ elseif ($action == "cp_folder")
 else
 {
    if (check_auth($id, "folder_move", $userid) == 0)
-   //if (check_auth($id, "folder_modify", $userid) == 0 or check_auth($id, "folder_delete", $userid) == 0 )
    {
       include($default->owl_fs_root ."/lib/header.inc");
       include($default->owl_fs_root ."/lib/userheader.inc");
@@ -108,7 +103,6 @@ function showFoldersIn($fid, $folder)
    // If restricted view is in effect only show the folders you do have access to
    $showfolder = 1;
    if ($default->restrict_view == 1)
-      //if (check_auth($fid, "folder_modify", $userid) != 0 && $fid != 0)
      if (check_auth($fid, "folder_create", $userid) != 0 && $fid != 0)
       {
          $showfolder = 1;
@@ -183,9 +177,9 @@ function showFoldersIn($fid, $folder)
                }
             }
          }
-         if (($moreFolder > 0) && ($fid == $id)) $gray = 1; //   subtree for folder moves
+         if (($moreFolder > 0) && ($fid == $id) and ($action == "folder" or $action == "cp_folder")) $gray = 1; //   subtree for folder moves
+         //print("fid: $fid ID: $id G: $gray");
          if (check_auth($fid, "folder_create", $userid) == 0)
-         //if (check_auth($fid, "folder_modify", $userid) == 0)
          {
             $gray = 1; //   check for permissions
          } 
@@ -289,7 +283,6 @@ function showFoldersIn($fid, $folder)
          {
             foreach($disp as $fid)
             {
-               //if (check_auth($fid, "file_modify", $userid) == 1)
                if (check_auth($fid, "file_move", $userid) == 1)
                {
                   if ($default->owl_use_fs)
@@ -313,91 +306,8 @@ function showFoldersIn($fid, $folder)
                      {
                         if (!file_exists("$default->owl_FileDir/$dest$fname"))
                         {
-                           if (substr(php_uname(), 0, 7) != "Windows")
-                           {
-                              $cmd = "mv \"$default->owl_FileDir/$source$fname\" \"$default->owl_FileDir/$dest\" 2>&1";
-                              $lines = array();
-                              $errco = 0;
-                              $result = myExec($cmd, $lines, $errco);
-                              if ($errco != 0)
-                              {
-                                 printError($owl_lang->err_movecancel, $result);
-                              } 
-                                                                                                                                                                                                                                                 
-                              // Check to see if this file has Other Versions as we have to move those files as well.
-                              $aFirstpExtension = fFindFileFirstpartExtension ($fname);
-                              $firstpart = $aFirstpExtension[0];
-                              $file_extension = $aFirstpExtension[1];
-
-                              // Get the id of the backup folder for the SOURCE Directory
-                              if ($default->owl_use_fs)
-                              {
-                                 $sql->query("SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$parent'");
-                                 if ($sql->num_rows($sql) != 0)
-                                 {
-                                    while ($sql->next_record())
-                                    {
-                                       $backup_parent = $sql->f("id");
-                                    }
-                                 }
-                                 else
-                                 {
-                                       $backup_parent = $parent;
-                                 }
-                                 // Get the id of the backup folder for the Destination Directory
-                                 // If it doesn't exists create one
-                                 $sql->query("SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$newFolder'");
-                                 //print("<br />SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$newFolder'<br />");
-                                 if ($sql->num_rows($sql) != 0)
-                                 {
-                                    while ($sql->next_record())
-                                    {
-                                       $BackupFolderId = $sql->f("id");
-                                    }
-                                 }
-                                 else
-                                 {
-                                    $sDestinationBackupDir = "$default->owl_FileDir/$dest/$default->version_control_backup_dir_name";
-                                    if (!is_dir($sDestinationBackupDir))
-                                    {
-                                       mkdir($sDestinationBackupDir, $default->directory_mask);
-                                       if (is_dir($sDestinationBackupDir))
-                                       {
-                                          $sql->query("INSERT INTO $default->owl_folders_table (name, parent, security, groupid, creatorid, description)  values ('$default->version_control_backup_dir_name', '$newFolder', '" . fCurFolderSecurity($newFolder) ."', '" . owlfoldergroup($newFolder) ."', '" . owlfoldercreator($newFolder) . "', '')");
-                                          $BackupFolderId = $sql->insert_id($default->owl_folders_table, 'id');
-                                                                                                                                                                                                                                                       
-                                       }
-                                       else
-                                       {
-                                          printError("$owl_lang->err_backup_folder_create");
-                                       }
-                                    }
-                                 }
-                                 // Move the Backup files to the Destination backup Directory
-                                 //print("<br /> BACK: $BackupFolderId <br />");
-                                 $qMoveBackupFiles = new Owl_DB;
-                                 $sql->query("SELECT * FROM $default->owl_files_table WHERE (filename LIKE '" . $firstpart . "\\_%" . $file_extension . "' OR filename = '$filename') AND (parent = '$backup_parent' OR parent = '$parent') ORDER BY major_revision desc, minor_revision desc");
-                                 //print("SELECT * FROM $default->owl_files_table WHERE (filename LIKE '" . $firstpart . "\\_%" . $file_extension . "' OR filename = '$filename') AND (parent = '$backup_parent' OR parent = '$parent') ORDER BY major_revision desc, minor_revision desc");
-                                 while ($sql->next_record())
-                                 {
-                                    $qMoveBackupFiles->query("UPDATE $default->owl_files_table SET parent='$BackupFolderId' WHERE id='" . $sql->f("id") ."'");
-                                    $cmd = "mv \"$default->owl_FileDir/$source/$default->version_control_backup_dir_name/" . $sql->f("filename") . "\" \"$default->owl_FileDir/$dest/$default->version_control_backup_dir_name/". $sql->f("filename") . "\" 2>&1";
-                                    //print("<br>CMD: $cmd");
-                                    $lines = array();
-                                    $errco = 0;
-                                    $result = myExec($cmd, $lines, $errco);
-                                    if ($errco != 0)
-                                    {
-                                       //printError($owl_lang->err_movecancel, $result);
-                                    }
-                                 }
-                              }
-                           } 
-                           else
-                           { 
-                              // IF Windows just do a rename and hope for the best
-                              rename ("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest/$fname");
-                           } 
+                           rename ("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest$fname");
+                           fMoveBackupVersions ($fname, $source, $dest, $parent);
                         } 
                         else
                         {
@@ -415,7 +325,6 @@ function showFoldersIn($fid, $folder)
             foreach($fdisp as $fid)
             {
                if (check_auth($fid, "folder_create", $userid) == 1)
-               //if (check_auth($fid, "folder_modify", $userid) == 1)
                {
                   if ($default->owl_use_fs)
                   {
@@ -443,6 +352,7 @@ function showFoldersIn($fid, $folder)
                         { 
                            // IF Windows just do a rename and hope for the best
                            rename ("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest/$fname");
+                           fWindowsMoveFolders("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest/$fname");
                         } 
                      } 
                      else
@@ -470,7 +380,6 @@ function showFoldersIn($fid, $folder)
             }
             $Realid = fGetPhysicalFileId($fid);
 
-            //printError("I: $id R: $Realid F: $fid", "T: $type");
             if ($type != "url" and $Realid == $fid)
             {
                if (!file_exists("$default->owl_FileDir/$dest$fname"))
@@ -491,7 +400,6 @@ function showFoldersIn($fid, $folder)
                      else if ( $action == "cp_folder")
                      {
                         my_dir_copy("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest" . fid_to_name($id) ); 
-                        //printError("S: $source N: $fname" , "$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest" . fid_to_name($id) ); 
                      }
                      else if ( $action == "folder")
                      {
@@ -506,83 +414,8 @@ function showFoldersIn($fid, $folder)
                      }
                      else 
                      {
-                        // Move the Actuall file
-                         $cmd = "mv \"$default->owl_FileDir/$source$fname\" \"$default->owl_FileDir/$dest\" 2>&1";
-                         $lines = array();
-                         $errco = 0;
-                         $result = myExec($cmd, $lines, $errco);
-                         if ($errco != 0)
-                         {
-                            printError($owl_lang->err_movecancel, $result);
-                         }
-
-                        // Check to see if this file has Other Versions as we have to move those files as well.
-                        
-                        $aFirstpExtension = fFindFileFirstpartExtension ($fname);
-                        $firstpart = $aFirstpExtension[0];
-                        $file_extension = $aFirstpExtension[1];
-
-                        // Get the id of the backup folder for the SOURCE Directory
-                        if ($default->owl_use_fs)
-                        {
-                           $sql->query("SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$parent'");
-                           if ($sql->num_rows($sql) != 0)
-                           {
-                              while ($sql->next_record())
-                              {
-                                 $backup_parent = $sql->f("id");
-                              }
-                           }
-                           else
-                           {
-                                 $backup_parent = $parent;
-                           }
-
-                           // Get the id of the backup folder for the Destination Directory
-                           // If it doesn't exists create one
-                           $sql->query("SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$newFolder'");
-                           //print("<br />SELECT id FROM $default->owl_folders_table WHERE name='$default->version_control_backup_dir_name' and parent='$newFolder'<br />");
-                           if ($sql->num_rows($sql) != 0)
-                           {
-                              while ($sql->next_record())
-                              {
-                                 $BackupFolderId = $sql->f("id");
-                              }
-                           }
-                           else
-                           {
-                              $sDestinationBackupDir = "$default->owl_FileDir/$dest/$default->version_control_backup_dir_name";
-                              if (!is_dir($sDestinationBackupDir))
-                              {
-                                 mkdir($sDestinationBackupDir, $default->directory_mask);
-                                 if (is_dir($sDestinationBackupDir))
-                                 {
-                                    $sql->query("INSERT INTO $default->owl_folders_table (name, parent, security, groupid, creatorid, description)  values ('$default->version_control_backup_dir_name', '$newFolder', '" . fCurFolderSecurity($newFolder) ."', '" . owlfoldergroup($newFolder) ."', '" . owlfoldercreator($newFolder) . "', '')");
-                                    $BackupFolderId = $sql->insert_id($default->owl_folders_table, 'id');                                                                                                                                                                                               
-                                 }
-                                 else
-                                 {
-                                    printError("$owl_lang->err_backup_folder_create");
-                                 }
-                              }
-                           }
-                           // Move the Backup files to the Destination backup Directory
-                           //print("<br /> BACK: $BackupFolderId <br />");
-                           $qMoveBackupFiles = new Owl_DB;
-                           $sql->query("SELECT * FROM $default->owl_files_table WHERE (filename LIKE '" . $firstpart . "\\_%" . $file_extension . "' OR filename = '$filename') AND (parent = '$backup_parent' OR parent = '$parent') ORDER BY major_revision desc, minor_revision desc");
-                           while ($sql->next_record())
-                           {
-                              $qMoveBackupFiles->query("UPDATE $default->owl_files_table SET parent='$BackupFolderId' WHERE id='" . $sql->f("id") ."'");
-                              $cmd = "mv \"$default->owl_FileDir/$source/$default->version_control_backup_dir_name/" . $sql->f("filename") . "\" \"$default->owl_FileDir/$dest/$default->version_control_backup_dir_name/". $sql->f("filename") . "\" 2>&1";
-                              $lines = array();
-                              $errco = 0;
-                              $result = myExec($cmd, $lines, $errco);
-                              if ($errco != 0)
-                              {
-                                 //printError($owl_lang->err_movecancel, $result);
-                              }
-                           }
-                        }
+                        rename("$default->owl_FileDir/$source$fname" , "$default->owl_FileDir/$dest$fname");
+                        fMoveBackupVersions ($fname, $source, $dest, $parent);
                      }
                   } 
                   else
@@ -600,6 +433,7 @@ function showFoldersIn($fid, $folder)
                      {
                         // IF Windows just do a rename and hope for the best
                         rename ("$default->owl_FileDir/$source$fname", "$default->owl_FileDir/$dest/$fname");
+                        fMoveBackupVersions ($fname, $source, $dest, $parent);
                      }
                   } 
                } 
@@ -613,7 +447,21 @@ function showFoldersIn($fid, $folder)
 
       if ($action == "file")
       {
-         $sql->query("UPDATE $default->owl_files_table SET parent='$newFolder' WHERE id='$id'");
+         if (!$default->owl_use_fs) 
+         {
+            // use_fs_false
+            $qMoveBackupFiles = new Owl_DB;
+            $sql->query("SELECT id FROM $default->owl_files_table WHERE  parent='$parent' AND  filename ='" . fid_to_filename($id) ."'");
+            while ($sql->next_record())
+            {
+               // move all the versions of the file
+               $qMoveBackupFiles->query("UPDATE $default->owl_files_table SET parent='$newFolder' WHERE id='" . $sql->f('id') . "'");
+            }
+         }
+         else
+         {
+            $sql->query("UPDATE $default->owl_files_table SET parent='$newFolder' WHERE id='$id'");
+         }
          owl_syslog(FILE_MOVED, $userid, flid_to_filename($id), $parent, $owl_lang->log_file_to . fid_to_name($newFolder), "FILE");
       } 
       else if ($action == "cp_file")
@@ -719,7 +567,6 @@ function showFoldersIn($fid, $folder)
          fPrintNavBar($parent, $owl_lang->moving_file . ":&nbsp;", $id);
       }
    }
-   //print("</TABLE><br />\n");
    // Get information about file or directory we want to move
    if ($action == "file")
    {
@@ -735,7 +582,6 @@ function showFoldersIn($fid, $folder)
       {
          foreach($disp as $fid)
          {
-            //if (check_auth($fid, "file_modify", $userid) == 1)
             if (check_auth($fid, "file_move", $userid) == 1)
             {
                $query .= "id = '" . $fid . "' or ";
@@ -749,7 +595,6 @@ function showFoldersIn($fid, $folder)
       {
       foreach($fdisp as $fid)
       {
-         //if (check_auth($fid, "folder_modify", $userid) == 1)
          if (check_auth($fid, "folder_move", $userid) == 1)
          {
             $query2 .= "id = '" . $fid . "' or ";
