@@ -9,7 +9,10 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  */
+
+ob_start();
 require_once(dirname(__FILE__)."/config/owl.php");
+$out = ob_get_clean();
 require_once($default->owl_fs_root ."/lib/disp.lib.php");
 
 
@@ -126,7 +129,14 @@ function printThankYou($username)
 {
    global $default, $language;
    global $owl_lang;
-
+   $sql = new Owl_DB;
+   $sql->query("SELECT * FROM $default->owl_users_table WHERE username = '$username' and disabled='1'");
+   $sMessage = "";
+   if ($sql->num_rows($sql) == 1)
+   {
+      $sMessage = $owl_lang->thank_you_3;
+   }
+   
    fPrintHeader();
 
    print("<table width=\"100%\"><tr><td class=\"form1\">");
@@ -135,7 +145,7 @@ function printThankYou($username)
    fPrintButtonSpace(12, 1);
 
    print("<table width=\"100%\"><tr><td class=\"form1\" align=\"center\">");
-   print("$owl_lang->thank_you_2 <b>$username</b>");
+   print("<b>$username</b> Created.<br />$owl_lang->thank_you_2<br />$sMessage");
    print("</td></tr></table>");
 
    fPrintButtonSpace(12, 1);
@@ -275,7 +285,7 @@ function printgetpasswd()
       print("     </tr>\n");
    }
 
-   fPrintFormTextLine($owl_lang->username . ":" , "username", "", $username);
+   fPrintFormTextLine($owl_lang->forgot_username . ":" , "username", "", $username);
    print("<tr>\n");
    print("<td class=\"form1\">");
    fPrintButtonSpace(1, 1);
@@ -362,7 +372,7 @@ if ($default->registration_using_captcha)
 
       }
 
-       $sql->query("INSERT INTO $default->owl_users_table (groupid,username,name,password,quota_max,quota_current,email,notify,attachfile,disabled,noprefaccess,language,maxsessions,curlogin, lastlogin,useradmin,newsadmin,buttonstyle, homedir, firstdir ) VALUES ('$default->self_reg_group', '$username', '$name', '" . md5($password) . "', '$default->self_reg_quota', '0', '$email', '$default->self_reg_notify','$default->self_reg_attachfile', '$default->self_reg_disabled', '$default->self_reg_noprefacces', '$default->owl_lang', '$default->self_reg_maxsessions', $dNow, $dNow, '0', '0', '$default->system_ButtonStyle', '$iHomeDir','$iInitial')");
+       $sql->query("INSERT INTO $default->owl_users_table (groupid,username,name,password,quota_max,quota_current,email,notify,attachfile,disabled,noprefaccess,language,maxsessions,curlogin, lastlogin,useradmin,newsadmin,buttonstyle, homedir, firstdir, user_auth ) VALUES ('$default->self_reg_group', '$username', '$name', '" . md5($password) . "', '$default->self_reg_quota', '0', '$email', '$default->self_reg_notify','$default->self_reg_attachfile', '$default->self_reg_disabled', '$default->self_reg_noprefacces', '$default->owl_lang', '$default->self_reg_maxsessions', $dNow, $dNow, '0', '0', '$default->system_ButtonStyle', '$iHomeDir','$iInitial', '$default->auth')");
 
       $iNewUserID =  $sql->insert_id($default->owl_users_table, 'id');
 
@@ -385,7 +395,18 @@ if ($default->registration_using_captcha)
             $mail->Username = "$default->smtp_auth_login "; // SMTP username
             $mail->Password = "$default->smtp_passwd"; // SMTP password
          } 
+         if ($ccto != "")
+         {
+            $mail->AddCC("$ccto");
+         }
       } 
+      else
+      {
+         if ($ccto != "")
+         {
+            $mail->AddAddress("$ccto");
+         }
+      }
       $mail->CharSet = "$owl_lang->charset"; // set the email charset to the language file charset 
       $mail->Host = "$default->owl_email_server"; // specify main and backup server
       $mail->From = "$default->owl_email_from";
@@ -393,18 +414,22 @@ if ($default->registration_using_captcha)
       $mail->AddAddress($email);
       $mail->AddReplyTo("$default->owl_email_replyto", "OWL Intranet");
 
-      if ($ccto != "")
-      {
-         $mail->AddCC("$ccto");
-      }
       $mail->WordWrap = 50; // set word wrap to 50 characters
       $mail->IsHTML(true); // set email format to HTML
-      $mail->Subject = "$owl_lang->self_reg_subj";
-      $mail->Body = "<html><body>" . "$owl_lang->self_reg_bod $password" . "<br /><br />";
-      $link = $default->owl_notify_link . "index.php" ;
-      $mail->Body .= "<A HREF=" . $link . ">$owl_lang->login</A>";
-      $mail->altBody = "$owl_lang->self_reg_bod $password" . "\n\n";
-      $mail->Body .= "</body></html>";
+
+      $aBody = fGetMailBodyText(SELF_REG_USER);
+
+      $mail->Subject = $aBody['SUBJECT'];
+
+      $aBody['HTML'] = ereg_replace("\%USERNAME\%", $username , $aBody['HTML'] );
+      $aBody['TXT'] = ereg_replace("\%USERNAME\%", $username , $aBody['TXT'] );
+
+      $aBody['HTML'] = ereg_replace("\%NEW_PASSWORD\%", $password . "<br />$sHtmlLink ", $aBody['HTML'] );
+      $aBody['TXT'] = ereg_replace("\%NEW_PASSWORD\%", $password . "\n $link", $aBody['TXT'] );
+
+
+      $mail->altBody = $aBody['TXT'];
+      $mail->Body = $aBody['HTML'];
 
       if (!$mail->Send())
       {
@@ -499,7 +524,7 @@ elseif ($myaction == "getpasswd")
    $password = GenRandPassword();
    $sql = new Owl_DB;
 
-   $sql->query("SELECT * FROM $default->owl_users_table WHERE username = '$username' AND id <> '1' AND disabled = '0'");
+   $sql->query("SELECT * FROM $default->owl_users_table WHERE username = '$username' or email ='$username' AND id <> '1' AND disabled = '0'");
 
    $failed = false;
 
@@ -512,10 +537,19 @@ elseif ($myaction == "getpasswd")
 
    if ($failed === false)
    {
-      $sql->query("SELECT email, user_auth FROM $default->owl_users_table WHERE username = '$username'");
+      $sql->query("SELECT id, username, email, user_auth FROM $default->owl_users_table WHERE username = '$username' or email ='$username' AND id <> '1' AND disabled = '0'");
       $sql->next_record();
       $email = $sql->f("email");
-      $sUserAuth = trim($sql->f("user_auth"));
+      $sUserName = $sql->f("username");
+      if (is_null($sql->f("user_auth")))
+      {
+         $sUserAuth = "0";
+      }
+      else
+      {
+         $sUserAuth = trim($sql->f("user_auth"));
+      }
+
       $mail = new phpmailer();
 
       $aBody = fGetMailBodyText(NEW_PASSWORD);
@@ -545,6 +579,9 @@ elseif ($myaction == "getpasswd")
          $link = $default->owl_notify_link . "index.php" ;
          $sHtmlLink = "<a href=\"" . $link . "\">$owl_lang->login</a>";
 
+         $aBody['HTML'] = ereg_replace("\%USERNAME\%", $sUserName , $aBody['HTML'] );
+         $aBody['TXT'] = ereg_replace("\%USERNAME\%", $sUserName , $aBody['TXT'] );
+
          $aBody['HTML'] = ereg_replace("\%NEW_PASSWORD\%", $password . "<br />$sHtmlLink ", $aBody['HTML'] );
          $aBody['TXT'] = ereg_replace("\%NEW_PASSWORD\%", $password . "\n $link", $aBody['TXT'] );
 
@@ -565,8 +602,8 @@ elseif ($myaction == "getpasswd")
          print("$owl_lang->err_email<br />");
          print("$mail->ErrorInfo");
       } 
-      $sql->query("UPDATE $default->owl_users_table set password = '" . md5($password) . "' WHERE username = '$username'");
-      $sql->query("SELECT id FROM $default->owl_users_table WHERE username = '$username'");
+      $sql->query("UPDATE $default->owl_users_table set password = '" . md5($password) . "' WHERE username = '$sUserName'");
+      $sql->query("SELECT id FROM $default->owl_users_table WHERE username = '$sUserName'");
       $sql->next_record();
       owl_syslog(FORGOT_PASS, $sql->f("id"), 0, 0, "$owl_lang->self_passwd $email", "LOGIN");
    }
