@@ -9,7 +9,7 @@
  * Copyright (c) 1999-2005 The Owl Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  * 
- * $Id: setacl.php,v 1.4 2006/03/06 17:39:34 b0zz Exp $
+ * $Id: setacl.php,v 1.8 2006/09/29 02:28:34 b0zz Exp $
  */
 
 require_once(dirname(__FILE__)."/config/owl.php");
@@ -18,14 +18,26 @@ require_once($default->owl_fs_root ."/lib/owl.lib.php");
 require_once($default->owl_fs_root ."/lib/security.lib.php");
 require_once($default->owl_fs_root ."/phpid3v2/class.id3.php");
 
-$groups = fGetGroups($userid, "SETTINGACL");
+if ($action == "file_acl")
+{
+   $sAclType = "SETTING_FILE_ACL";
+}
+else
+{
+   $sAclType = "SETTING_FOLDER_ACL";
+}
+$groups = fGetGroups($userid, $sAclType, $id);
+
 $groups[-1][0] = "-1";
 $groups[-1][1] = "None";
-$aUserList = fGetUserInfoInMyGroups($userid);
+
+$aUserList = fGetUserInfoInMyGroups($userid, "", false, $sAclType, $id);
 
 $aUserList[0][username] = "everybody";
 $aUserList[0][name] = "EVERYBODY";
+$aUserList[0][email] = "";
 $aUserList[0][id] = "0";
+
 if($edit == 1)
 {
    //if (($action == "file_acl" and fIsFileCreator($id)) or ($action == "file_acl" and fisAdmin()))
@@ -76,6 +88,23 @@ if($edit == 1)
 
 include_once($default->owl_fs_root ."/lib/header.inc");
 include_once($default->owl_fs_root ."/lib/userheader.inc");
+?>
+<script type="text/javascript">
+var IE = document.all?true:false
+if (!IE) document.captureEvents(Event.MOUSEMOVE)
+document.onmousemove = getMouseY;
+
+function getMouseY(e) {
+  if (IE) { // grab the x-y pos.s if browser is IE
+    tempY = event.clientY + document.body.scrollTop
+  } else {  // grab the x-y pos.s if browser is NS
+    tempY = e.pageY
+  }
+  return true;
+}
+
+</script>
+<?php
 printModifyHeader();
 //print("<pre>");
 //print_r($selectedusers);
@@ -135,6 +164,128 @@ if ($action == "folder_acl")
       fPrintSectionHeader($owl_lang->acl_heading_folders);
       print("</table>");
       print("</td></tr></table><br />");
+if ($default->show_users_in_group === true)
+{
+   ?>
+<script type="text/javascript">
+//Function alerts the index of the selected option within form
+
+var ftooltipContentData = [
+
+<?php
+
+   $qGetUserMember = new Owl_DB;
+
+   //$groups[] = array(0 => '13', 1 => 'RVC');
+   //$groups = array();
+   //$groups[0][0] = "13";
+   //$groups[0][1] = "RVC";
+
+   //print("<pre>");
+   //print_r($groups);
+   //print("</pre>");
+   //exit;
+
+   
+   foreach($groups as $g)
+   {
+      if ($g[0] == -1)
+      {
+         continue;
+      }
+
+      if (!empty($fselectedgroups))
+      {
+         if (!(in_array($g[0], $fselectedgroups)))
+         {
+            $qSetAcl = "SELECT distinct id,name, username FROM $default->owl_users_table u left join $default->owl_users_grpmem_table m on u.id = m.userid where u.groupid = '$g[0]' or m.groupid = '$g[0]'";
+            //$qSetAcl = "SELECT name, username FROM $default->owl_users_table where groupid = '$g[0]'";
+            $qGetUserMember->query($qSetAcl);
+            print("'<table>");
+            if ($qGetUserMember->num_rows() == 0)
+            {
+               print("<tr><td>None</td></tr>");
+            }
+            while($qGetUserMember->next_record())
+            {
+               print("<tr><td>" . $qGetUserMember->f('name') . "</td><td>(" . $qGetUserMember->f('username') . ")</td></tr>");
+            }
+            print("</table>',\n");
+         }
+      }
+      else
+      {
+         //$qSetAcl = "SELECT name, username FROM $default->owl_users_table where groupid = '$g[0]'";
+         $qSetAcl = "SELECT distinct id,name, username FROM $default->owl_users_table u left join $default->owl_users_grpmem_table m on u.id = m.userid where u.groupid = '$g[0]' or m.groupid = '$g[0]'";
+         $qGetUserMember->query($qSetAcl);
+         print("'<table>");
+	 if ($qGetUserMember->num_rows() == 0)
+	 {
+	    print("<tr><td>None</td></tr>");
+	 }
+         while($qGetUserMember->next_record())
+         {
+            print("<tr><td>" . $qGetUserMember->f('name') . "</td><td>(" . $qGetUserMember->f('username') . ")</td></tr>");
+         }
+         print("</table>',\n");
+      }
+
+   }
+   print ("''\n");
+
+	//'No content yet.  Click one of the links below.',
+	//'What would you like to do today?',
+	//'Implement tooltips on your site?  <b>Excellent!</b>',
+	//'You should definitely consider using domTT.'
+?>
+];
+
+var ftooltipCaptionData = [
+
+<?php
+
+   $qGetUserMember = new Owl_DB;
+
+   foreach($groups as $g)
+   {
+      if ($g[0] == -1)
+      {
+         continue;
+      }
+
+      if (!empty($fselectedgroups))
+      {
+         if (!(in_array($g[0], $fselectedgroups)))
+         {
+            print("'Users in: $g[1]',");
+         }
+      }
+      else
+      {
+         print("'Users in: $g[1]',");
+      }
+
+   }
+   print ("''\n");
+
+?>
+];
+
+
+var ftooltipContentIndex = 0;
+function fgetTooltipContent() {
+	return ftooltipContentData[ftooltipContentIndex];
+}
+function fgetTooltipCaption() {
+	return ftooltipCaptionData[ftooltipContentIndex];
+}
+
+function fgetselectedvalue(gbox){
+return(gbox.selectedIndex)
+}
+</script>
+<?php
+}
 
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
       print("<tr>\n<td align=\"center\" valign=\"top\">");
@@ -150,7 +301,13 @@ if ($action == "folder_acl")
       print("</tr>\n");
       print("<tr>\n");
       print("<td class=\"form1\">\n");
-      print("<select multiple=\"multiple\" size=\"10\" name=\"fallgroups[]\" class=\"fpullacl\">\n");
+      print("<select multiple=\"multiple\" size=\"10\" name=\"fallgroups[]\" class=\"fpullacl\"");
+   //    print (" onchange=\"tooltipContentIndex = getselectedvalue(this); domTT_activate(this, event, 'content', getTooltipContent(), 'lifetime', 5000, 'closeAction', 'destroy', 'styleClass', 'niceTitle', 'x', 50, 'y', 50);\"");
+if ($default->show_users_in_group === true)
+{
+   print (" onchange=\"ftooltipContentIndex = fgetselectedvalue(this); domTT_activate(this, event, 'content', fgetTooltipContent(), 'type', 'sticky', 'closeLink', '&nbsp; [x] &nbsp;', 'draggable', true, 'closeAction', 'destroy',  'caption' , fgetTooltipCaption(), 'x', 50, 'y', tempY);\"");
+}
+      print(">\n");
       foreach($groups as $g)
       {
          if ($g[0] == -1)
@@ -209,7 +366,11 @@ if ($action == "folder_acl")
       print("</tr>\n");
       print("<tr>\n");
       print("<td class=\"form1\">\n");
-      print("<select multiple=\"multiple\" size=\"10\" name=\"fallusers[]\" class=\"fpullacl\">\n");
+      print("<select multiple=\"multiple\" size=\"10\" name=\"fallusers[]\" class=\"fpullacl\"");
+
+
+
+      print(">\n");
       if (!empty($aUserList))
       {
          foreach ($aUserList as $aUsers)
@@ -621,7 +782,7 @@ function fPrintSetFileAcl($id, $type = "user")
 
 function fPrintSelectFileUserGroups($type = "user")
 {
-   global $owl_lang, $groups, $selectedgroups, $aUserList, $selectedusers;
+   global $default, $owl_lang, $groups, $selectedgroups, $aUserList, $selectedusers;
 
       print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
       print("<tr>\n<td align=\"center\" valign=\"top\">");
@@ -643,7 +804,122 @@ function fPrintSelectFileUserGroups($type = "user")
 
    print("<tr>\n");
    print("<td class=\"form1\">\n");
-   print("<select multiple=\"multiple\" size=\"10\" name=\"allgroups[]\" class=\"fpullacl\">\n");
+
+if ($default->show_users_in_group === true)
+{
+   ?>
+<script type="text/javascript">
+//Function alerts the index of the selected option within form
+
+var tooltipContentData = [
+
+<?php
+
+   $qGetUserMember = new Owl_DB;
+   
+   foreach($groups as $g)
+   {
+      if ($g[0] == -1)
+      {
+         continue;
+      }
+
+      if (!empty($selectedgroups))
+      {
+         if (!(in_array($g[0], $selectedgroups)))
+         {
+            $qSetAcl = "SELECT distinct id,name, username FROM $default->owl_users_table u left join $default->owl_users_grpmem_table m on u.id = m.userid where u.groupid = '$g[0]' or m.groupid = '$g[0]'";
+            //$qSetAcl = "SELECT name, username FROM $default->owl_users_table where groupid = '$g[0]'";
+            $qGetUserMember->query($qSetAcl);
+            print("'<table>");
+            if ($qGetUserMember->num_rows() == 0)
+            {
+               print("<tr><td>None</td></tr>");
+            }
+            while($qGetUserMember->next_record())
+            {
+               print("<tr><td>" . $qGetUserMember->f('name') . "</td><td>(" . $qGetUserMember->f('username') . ")</td></tr>");
+            }
+            print("</table>',\n");
+         }
+      }
+      else
+      {
+         $qSetAcl = "SELECT distinct id,name, username FROM $default->owl_users_table u left join $default->owl_users_grpmem_table m on u.id = m.userid where u.groupid = '$g[0]' or m.groupid = '$g[0]'";
+         //$qSetAcl = "SELECT name, username FROM $default->owl_users_table where groupid = '$g[0]'";
+         $qGetUserMember->query($qSetAcl);
+         print("'<table>");
+         if ($qGetUserMember->num_rows() == 0)
+         {
+            print("<tr><td>None</td></tr>");
+         }
+         while($qGetUserMember->next_record())
+         {
+            print("<tr><td>" . $qGetUserMember->f('name') . "</td><td>(" . $qGetUserMember->f('username') . ")</td></tr>");
+         }
+         print("</table>',\n");
+      }
+
+   }
+   print ("''\n");
+
+?>
+];
+
+var tooltipCaptionData = [
+
+<?php
+
+   $qGetUserMember = new Owl_DB;
+
+   foreach($groups as $g)
+   {
+      if ($g[0] == -1)
+      {
+         continue;
+      }
+
+      if (!empty($selectedgroups))
+      {
+         if (!(in_array($g[0], $selectedgroups)))
+         {
+            print("'Users in: $g[1]',");
+         }
+      }
+      else
+      {
+         print("'Users in: $g[1]',");
+      }
+
+   }
+   print ("''\n");
+
+?>
+];
+
+
+var tooltipContentIndex = 0;
+function getTooltipContent() {
+	return tooltipContentData[tooltipContentIndex];
+}
+function getTooltipCaption() {
+	return tooltipCaptionData[tooltipContentIndex];
+}
+
+function getselectedvalue(gbox){
+return(gbox.selectedIndex)
+}
+
+</script>
+<?php
+}
+   print("<select multiple=\"multiple\" size=\"10\" name=\"allgroups[]\" class=\"fpullacl\"");
+   //print (" onchange=\"tooltipContentIndex = getselectedvalue(this); domTT_activate(this, event, 'content', getTooltipContent(), 'lifetime', 3000, 'closeAction', 'destroy', 'styleClass', 'niceTitle', 'x', 50, 'y', 50, 'type', 'sticky');\"");
+if ($default->show_users_in_group === true)
+{
+   print (" onchange=\"tooltipContentIndex = getselectedvalue(this); domTT_activate(this, event, 'content', getTooltipContent(), 'type', 'sticky', 'closeLink', '&nbsp; [x] &nbsp; ', 'draggable', true, 'closeAction', 'destroy', 'caption' , getTooltipCaption(), 'x', 50, 'y', tempY);\"");
+}
+   print(">\n");
 
    foreach($groups as $g)
    {
