@@ -239,18 +239,15 @@ if(!$default->old_action_icons)
    }
    $mid->setIconwww($default->owl_graphics_url . "/$default->sButtonStyle/icon_action/");
    $mid->setIconsize(17, 20);
-                                                                                                                                                                          
+
    fSetupFileActionMenus($qFileQuery);
    if (!empty($qSqlQuery))
    {
       fSetupFolderActionMenus($qFolderQuery);
    }
-                                                                                                                                                                          
    $mid->printHeader();
-                                                                                                                                                                          
 }
 
-
 include_once($default->owl_fs_root ."/lib/header.inc");
 include_once($default->owl_fs_root ."/lib/userheader.inc");
 
@@ -290,7 +287,9 @@ switch ($type)
      print("<table class=\"margin2\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\" width=\"100%\">\n");
      print("<form action=\"showrecords.php\" method=\"post\">\n");
      print fGetHiddenFields ($urlArgs);
-     fPrintFormTextLine("Past number of Days :" , "filter", 10);
+     fPrintFormTextLine($owl_lang->past_number, "filter", 10);
+
+$owl_lang->past_number = "Past number of Days :";
      print("<tr>\n<td colspan=\"2\" class=\"form2\" width=\"100%\">");
      fPrintSubmitButton($owl_lang->btn_submit, $owl_lang->alt_btn_submit, "submit", "submit");
      fPrintSubmitButton($owl_lang->btn_reset, $owl_lang->alt_reset_form, "reset");
@@ -460,17 +459,24 @@ if ($type == "t" or $type == "br")
  
          $CountLines++;
          $PrintLines = $CountLines % 2;
-         print("<tr>\n");
+
          if ($PrintLines == 0)
          {
-            $sTrClass = "file1";
+            $sTrClass = "hover1";
             $sLfList = "lfile1";
+            $sTrClassHilite = "mouseover1";
+            $sTrClassHiliteAlt = "mouseover3";
          }
          else
          {
-            $sTrClass = "file2";
+            $sTrClass = "hover2";
             $sLfList = "lfile1";
+            $sTrClassHilite = "mouseover2";
+            $sTrClassHiliteAlt = "mouseover3";
          }
+      
+         print("\t\t\t\t<tr class=\"$sTrClassHilite\" onMouseOver=\"this.className='$sTrClassHiliteAlt'\" onMouseOut=\"this.className='$sTrClassHilite'\">");
+
       //*******************************************************************************************************
 
    if(($default->expand_disp_status and $expand == 1) or ($default->collapse_disp_status and $expand == 0))
@@ -847,18 +853,23 @@ while ($sql->next_record())
 
    $CountLines++;
    $PrintLines = $CountLines % 2;
-   print("\t\t\t\t<tr>\n");
-   if ($PrintLines == 0)
+ if ($PrintLines == 0)
    {
-      $sTrClass = "file1";
+      $sTrClass = "hover1";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover1";
+      $sTrClassHiliteAlt = "mouseover3";
    }
    else
    {
-      $sTrClass = "file2";
+      $sTrClass = "hover2";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover2";
+      $sTrClassHiliteAlt = "mouseover3";
    }
 
+   print("\t\t\t\t<tr class=\"$sTrClassHilite\" onMouseOver=\"this.className='$sTrClassHiliteAlt'\" onMouseOut=\"this.className='$sTrClassHilite'\">");
+
    if(($default->expand_disp_status and $expand == 1) or ($default->collapse_disp_status and $expand == 0))
    {
       print("<td class=\"$sTrClass\" align=\"left\">");
