@@ -74,7 +74,7 @@
    }
    if (($default->expand_disp_updated and $expand == 1) or ($default->collapse_disp_updated and $expand == 0))
    {
-      show_link("updatorid", "sortupdator", $sortupdator, $order, $sess, $expand, $parent, "UPDATED BY");
+      show_link("updatorid", "sortupdator", $sortupdator, $order, $sess, $expand, $parent, $owl_lang->updated_by);
    }
    if (($default->expand_disp_modified and $expand == 1) or ($default->collapse_disp_modified and $expand == 0))
    {
@@ -105,7 +105,45 @@
       }
    }
 
+$sql = new Owl_DB;
 $sql->query($FolderQuery);
+
+?>
+<script language="JavaScript">
+
+function mark_selected(id, checkbox, currentclass) {
+
+identity=document.getElementById(id);
+if (checkbox.checked)
+{
+   identity.className="mouseover3";
+}
+else
+{
+   identity.className=currentclass;
+}
+
+}
+
+
+function alt_css_style(checkboxid, tr, newclassname) {
+
+
+checkbox=document.getElementById(checkboxid);
+if (!checkbox.checked)
+{
+   tr.className = newclassname;
+}
+
+}
+
+</script>
+<?php
+
+
+
+
+
 // **********************
 // BEGIN Print Folders
 // **********************
@@ -161,22 +199,28 @@ while ($sql->next_record())
    
    if ($PrintLines == 0)
    {
-      $sTrClass = "file1";
+      $sTrClass = "hover1";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover1";
+      $sTrClassHiliteAlt = "mouseover3";
    }
    else
    {
-      $sTrClass = "file2";
+      $sTrClass = "hover2";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover2";
+      $sTrClassHiliteAlt = "mouseover3";
    }
  
-   print("\t\t\t\t<tr>\n");
+   //print("\t\t\t\t<tr id=\"foldertr" . $sql->f("id") . "\" class=\"$sTrClassHilite\" onmouseover=\"alt_css_style('checkid" . $sql->f("id") . "', this, '$sTrClassHiliteAlt')\" this.className='$sTrClassHiliteAlt'\" onmouseout=\"this.className='$sTrClassHilite'\">\n");
+   print("\t\t\t\t<tr id=\"foldertr" . $sql->f("id") . "\" class=\"$sTrClassHilite\" onmouseover=\"alt_css_style('fcheckid" . $sql->f("id") . "', this, '$sTrClassHiliteAlt')\"  onmouseout=\"alt_css_style('fcheckid" . $sql->f("id") . "', this, '$sTrClassHilite')\">\n");
+   //print("\t\t\t\t<tr id=\"foldertr" . $sql->f("id") . "\" class=\"$sTrClassHilite\">\n");
    if ($default->show_bulk > 0 or (fIsAdmin() and $default->show_bulk == 0 ))
    {
       if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
       {
          print("<td class=\"$sTrClass\">");
-         print("<input type=\"checkbox\" name=\"fbatch[]\" value=\"" . $sql->f("id") . "\"></input>");
+         print("<input id=\"fcheckid" .  $sql->f("id") . "\" type=\"checkbox\" name=\"fbatch[]\" value=\"" . $sql->f("id") . "\" onclick=\"mark_selected('foldertr" . $sql->f("id") . "', this, '$sTrClassHilite')\"></input>");
          print("</td>");
       } 
    } 
@@ -212,7 +256,7 @@ while ($sql->next_record())
    {
       print("<td class=\"$sTrClass\">");
       //$sPopupDescription = ereg_replace("\n", '<br />', trim($sql->f("description")));
-      $sPopupDescription = nl2br(trim($sql->f("description")));
+      $sPopupDescription = nl2br(trim(htmlentities($sql->f("description"))));
    
       $urlArgs2 = $urlArgs;
       $urlArgs2['parent'] = $sql->f("id");
@@ -607,6 +651,7 @@ $sql = new Owl_DB;
       }
    }
 
+//print("Q: $FileQuery");
 $sql->query($FileQuery);
 
 while ($sql->next_record())
@@ -657,7 +702,12 @@ while ($sql->next_record())
    $bHasComments = true;
    $bPrintNewComment = false;
 
-   $CheckComments = new Owl_DB;
+   $CheckComments = $cCommonDBConnection;
+
+   if (empty($CheckComments))
+   {
+      $CheckComments = new Owl_DB;
+   }
 
    $CheckComments->query("SELECT * from $default->owl_comment_table where fid = '" . $sql->f("id") . "' order by comment_date desc");
 
@@ -695,25 +745,34 @@ while ($sql->next_record())
 
    $CountLines++;
    $PrintLines = $CountLines % 2;
- 
+
    if ($PrintLines == 0)
    {
-      $sTrClass = "file1";
+      $sTrClass = "hover1";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover1";
+      $sTrClassHiliteAlt = "mouseover3";
    }
    else
    {
-      $sTrClass = "file2";
+      $sTrClass = "hover2";
       $sLfList = "lfile1";
+      $sTrClassHilite = "mouseover2";
+      $sTrClassHiliteAlt = "mouseover3";
    }
-      print("\t\t\t\t<tr>");
+ 
+   //print("\t\t\t\t<tr id=\"filetr" . $sql->f("id") . \" class=\"$sTrClassHilite\" onmouseover=\"this.className='$sTrClassHiliteAlt'\" onmouseout=\"this.className='$sTrClassHilite'\">");
+   //print("\t\t\t\t<tr id=\"filetr" . $sql->f("id") . "\" class=\"$sTrClassHilite\">");
+   print("\t\t\t\t<tr id=\"filetr" . $sql->f("id") . "\" class=\"$sTrClassHilite\" onmouseover=\"alt_css_style('checkid" . $sql->f("id") . "', this, '$sTrClassHiliteAlt')\"  onmouseout=\"alt_css_style('checkid" . $sql->f("id") . "', this, '$sTrClassHilite')\">\n");
+
 
    if ($default->show_bulk > 0 or (fIsAdmin() and $default->show_bulk == 0 ))
    {
       if ($sess != "0" || ($sess == "0" && $default->anon_ro == 0))
       {
          print("<td class=\"$sTrClass\">");
-         print("<input type=\"checkbox\" name=\"batch[]\" value=\"" . $sql->f("id") . "\"></input>");
+         print("<input id=\"checkid" .  $sql->f("id") . "\" type=\"checkbox\" name=\"batch[]\" value=\"" . $sql->f("id") . "\" onclick=\"mark_selected('filetr" . $sql->f("id") . "', this, '$sTrClassHilite')\"></input>");
+
          print("</td>");
       } 
    } 
@@ -879,13 +938,14 @@ while ($sql->next_record())
       {
          $sPopupDescription = $owl_lang->no_description;
       }
+
       $urlArgs2 = $urlArgs;
       $urlArgs2['sess']   = $sess;
       $urlArgs2['id']     = $sql->f("id");
       $urlArgs2['parent'] = $parent;
       $urlArgs2['action'] = 'file_details';
       $url = fGetURL ('view.php', $urlArgs2);
-   
+  
       print("\n<a class=\"$sLfList\" href=\"$url\" onmouseover=" . '"' . "return makeTrue(domTT_activate(this, event, 'caption', '" . $owl_lang->description . "', 'content', '" . $sPopupDescription . "', 'lifetime', 3000, 'fade', 'both', 'delay', 10, 'statusText', ' ', 'trail', true));" . '"');
    
       print(">\n");
